@@ -5,20 +5,16 @@ Run benchmarks with::
     import nibabel as nib
     nib.bench()
 
-If you have doctests enabled by default in nose (with a noserc file or
-environment variable), and you have a numpy version <= 1.6.1, this will also
-run the doctests, let's hope they pass.
+Run this benchmark with::
 
-Run this benchmark with:
-
-    nosetests -s --match '(?:^|[\\b_\\.//-])[Bb]ench' /path/to/bench_arrayproxy_slicing.py
+    pytest -c <path>/benchmarks/pytest.benchmark.ini <path>/benchmarks/bench_arrayproxy_slicing.py
 """
 
 from timeit import timeit
 import gc
 import itertools as it
 import numpy as np
-import mock
+from unittest import mock
 
 import nibabel as nib
 from nibabel.tmpdirs import InTemporaryDirectory
