@@ -5,19 +5,13 @@ Run benchmarks with::
     import nibabel as nib
     nib.bench()
 
-If you have doctests enabled by default in nose (with a noserc file or
-environment variable), and you have a numpy version <= 1.6.1, this will also run
-the doctests, let's hope they pass.
+Run this benchmark with::
 
-Run this benchmark with:
-
-    nosetests -s --match '(?:^|[\\b_\\.//-])[Bb]ench' /path/to/bench_streamlines.py
+    pytest -c <path>/benchmarks/pytest.benchmark.ini <path>/benchmarks/bench_streamlines.py
 """
-from __future__ import division, print_function
 
 import numpy as np
 
-from six.moves import zip
 from nibabel.tmpdirs import InTemporaryDirectory
 
 from numpy.testing import assert_array_equal
