@@ -11,7 +11,6 @@ This can either be an actual numpy array, or an object that:
 import numpy as np
 
 from .filebasedimages import FileBasedImage
-from .keywordonly import kw_only_meth
 from .deprecated import deprecate_with_version
 
 
@@ -56,6 +55,11 @@ class DataobjImage(FileBasedImage):
     def _data(self):
         return self._dataobj
 
+    @deprecate_with_version('get_data() is deprecated in favor of get_fdata(),'
+                            ' which has a more predictable return type. To '
+                            'obtain get_data() behavior going forward, use '
+                            'numpy.asanyarray(img.dataobj).',
+                            '3.0', '5.0')
     def get_data(self, caching='fill'):
         """ Return image data from image with any necessary scaling applied
 
@@ -63,8 +67,8 @@ class DataobjImage(FileBasedImage):
 
             We recommend you use the ``get_fdata`` method instead of the
             ``get_data`` method, because it is easier to predict the return
-            data type.  We will deprecate the ``get_data`` method around April
-            2018, and remove it around April 2020.
+            data type.  ``get_data`` will be deprecated around November 2019
+            and removed around November 2021.
 
             If you don't care about the predictability of the return data type,
             and you want the minimum possible data size in memory, you can
@@ -345,7 +349,10 @@ class DataobjImage(FileBasedImage):
         if self._fdata_cache is not None:
             if self._fdata_cache.dtype.type == dtype.type:
                 return self._fdata_cache
-        data = np.asanyarray(self._dataobj).astype(dtype, copy=False)
+        # Always return requested data type
+        # For array proxies, will attempt to confine data array to dtype
+        # during scaling
+        data = np.asanyarray(self._dataobj, dtype=dtype)
         if caching == 'fill':
             self._fdata_cache = data
         return data
@@ -407,13 +414,12 @@ class DataobjImage(FileBasedImage):
         return self.shape
 
     @classmethod
-    @kw_only_meth(1)
-    def from_file_map(klass, file_map, mmap=True, keep_file_open=None):
+    def from_file_map(klass, file_map, *, mmap=True, keep_file_open=None):
         ''' Class method to create image from mapping in ``file_map``
 
         .. deprecated:: 2.4.1
             ``keep_file_open='auto'`` is redundant with `False` and has
-            been deprecated. It will raise an error in nibabel 3.0.
+            been deprecated. It raises an error as of nibabel 3.0.
 
         Parameters
         ----------
@@ -445,13 +451,12 @@ class DataobjImage(FileBasedImage):
         raise NotImplementedError
 
     @classmethod
-    @kw_only_meth(1)
-    def from_filename(klass, filename, mmap=True, keep_file_open=None):
+    def from_filename(klass, filename, *, mmap=True, keep_file_open=None):
         '''Class method to create image from filename `filename`
 
         .. deprecated:: 2.4.1
             ``keep_file_open='auto'`` is redundant with `False` and has
-            been deprecated. It will raise an error in nibabel 3.0.
+            been deprecated. It raises an error as of nibabel 3.0.
 
         Parameters
         ----------
