@@ -7,9 +7,8 @@ from os.path import join as pjoin
 
 from io import BytesIO
 
-from nibabel.testing import data_path
-from nibabel.testing import clear_and_catch_warnings, assert_arr_dict_equal
-from nose.tools import assert_equal, assert_raises, assert_true
+import pytest
+from ...testing import data_path, clear_and_catch_warnings, assert_arr_dict_equal
 from numpy.testing import assert_array_equal
 
 from .test_tractogram import assert_tractogram_equal
@@ -23,7 +22,7 @@ from ..header import Field
 DATA = {}
 
 
-def setup():
+def setup_module():
     global DATA
 
     DATA['empty_trk_fname'] = pjoin(data_path, "empty.trk")
@@ -132,45 +131,51 @@ class TestTRK(unittest.TestCase):
         trk_struct[Field.VOXEL_TO_RASMM] = np.zeros((4, 4))
         with clear_and_catch_warnings(record=True, modules=[trk_module]) as w:
             trk = TrkFile.load(BytesIO(trk_bytes))
-            assert_equal(len(w), 1)
-            assert_true(issubclass(w[0].category, HeaderWarning))
-            assert_true("identity" in str(w[0].message))
+            assert len(w) == 1
+            assert issubclass(w[0].category, HeaderWarning)
+            assert "identity" in str(w[0].message)
             assert_array_equal(trk.affine, np.eye(4))
 
         # Simulate a TRK where `vox_to_ras` is invalid.
         trk_struct, trk_bytes = self.trk_with_bytes()
         trk_struct[Field.VOXEL_TO_RASMM] = np.diag([0, 0, 0, 1])
         with clear_and_catch_warnings(record=True, modules=[trk_module]) as w:
-            assert_raises(HeaderError, TrkFile.load, BytesIO(trk_bytes))
+            with pytest.raises(HeaderError):
+                TrkFile.load(BytesIO(trk_bytes))
 
         # Simulate a TRK file where `voxel_order` was not provided.
         trk_struct, trk_bytes = self.trk_with_bytes()
         trk_struct[Field.VOXEL_ORDER] = b''
         with clear_and_catch_warnings(record=True, modules=[trk_module]) as w:
             TrkFile.load(BytesIO(trk_bytes))
-            assert_equal(len(w), 1)
-            assert_true(issubclass(w[0].category, HeaderWarning))
-            assert_true("LPS" in str(w[0].message))
+            assert len(w) == 1
+            assert issubclass(w[0].category, HeaderWarning)
+            assert "LPS" in str(w[0].message)
 
         # Simulate a TRK file with an unsupported version.
         trk_struct, trk_bytes = self.trk_with_bytes()
         trk_struct['version'] = 123
-        assert_raises(HeaderError, TrkFile.load, BytesIO(trk_bytes))
+        with pytest.raises(HeaderError):
+            TrkFile.load(BytesIO(trk_bytes))
+        
 
         # Simulate a TRK file with a wrong hdr_size.
         trk_struct, trk_bytes = self.trk_with_bytes()
         trk_struct['hdr_size'] = 1234
-        assert_raises(HeaderError, TrkFile.load, BytesIO(trk_bytes))
+        with pytest.raises(HeaderError):
+            TrkFile.load(BytesIO(trk_bytes))
 
         # Simulate a TRK file with a wrong scalar_name.
         trk_struct, trk_bytes = self.trk_with_bytes('complex_trk_fname')
         trk_struct['scalar_name'][0, 0] = b'colors\x003\x004'
-        assert_raises(HeaderError, TrkFile.load, BytesIO(trk_bytes))
+        with pytest.raises(HeaderError):
+            TrkFile.load(BytesIO(trk_bytes))
 
         # Simulate a TRK file with a wrong property_name.
         trk_struct, trk_bytes = self.trk_with_bytes('complex_trk_fname')
         trk_struct['property_name'][0, 0] = b'colors\x003\x004'
-        assert_raises(HeaderError, TrkFile.load, BytesIO(trk_bytes))
+        with pytest.raises(HeaderError):
+            TrkFile.load(BytesIO(trk_bytes))
 
     def test_load_trk_version_1(self):
         # Simulate and test a TRK (version 1).
@@ -183,9 +188,9 @@ class TestTRK(unittest.TestCase):
         trk_struct['version'] = 1
         with clear_and_catch_warnings(record=True, modules=[trk_module]) as w:
             trk = TrkFile.load(BytesIO(trk_bytes))
-            assert_equal(len(w), 1)
-            assert_true(issubclass(w[0].category, HeaderWarning))
-            assert_true("identity" in str(w[0].message))
+            assert len(w) == 1
+            assert issubclass(w[0].category, HeaderWarning)
+            assert "identity" in str(w[0].message)
             assert_array_equal(trk.affine, np.eye(4))
             assert_array_equal(trk.header['version'], 1)
 
@@ -195,8 +200,8 @@ class TestTRK(unittest.TestCase):
         # We use hdr_size as an indicator of little vs big endian.
         good_orders = '>' if sys.byteorder == 'little' else '>='
         hdr_size = trk_struct['hdr_size']
-        assert_true(hdr_size.dtype.byteorder in good_orders)
-        assert_equal(hdr_size, 1000)
+        assert hdr_size.dtype.byteorder in good_orders
+        assert hdr_size == 1000
 
         for lazy_load in [False, True]:
             trk = TrkFile.load(DATA['complex_trk_big_endian_fname'],
@@ -205,7 +210,7 @@ class TestTRK(unittest.TestCase):
 
     def test_tractogram_file_properties(self):
         trk = TrkFile.load(DATA['simple_trk_fname'])
-        assert_equal(trk.streamlines, trk.tractogram.streamlines)
+        assert trk.streamlines == trk.tractogram.streamlines
         assert_array_equal(trk.affine, trk.header[Field.VOXEL_TO_RASMM])
 
     def test_write_empty_file(self):
@@ -223,8 +228,7 @@ class TestTRK(unittest.TestCase):
         assert_tractogram_equal(new_trk.tractogram, new_trk_orig.tractogram)
 
         trk_file.seek(0, os.SEEK_SET)
-        assert_equal(trk_file.read(),
-                     open(DATA['empty_trk_fname'], 'rb').read())
+        assert trk_file.read() == open(DATA['empty_trk_fname'], 'rb').read()
 
     def test_write_simple_file(self):
         tractogram = Tractogram(DATA['streamlines'],
@@ -242,8 +246,7 @@ class TestTRK(unittest.TestCase):
         assert_tractogram_equal(new_trk.tractogram, new_trk_orig.tractogram)
 
         trk_file.seek(0, os.SEEK_SET)
-        assert_equal(trk_file.read(),
-                     open(DATA['simple_trk_fname'], 'rb').read())
+        assert trk_file.read() == open(DATA['simple_trk_fname'], 'rb').read()
 
     def test_write_complex_file(self):
         # With scalars
@@ -292,8 +295,7 @@ class TestTRK(unittest.TestCase):
         assert_tractogram_equal(new_trk.tractogram, new_trk_orig.tractogram)
 
         trk_file.seek(0, os.SEEK_SET)
-        assert_equal(trk_file.read(),
-                     open(DATA['complex_trk_fname'], 'rb').read())
+        assert trk_file.read() == open(DATA['complex_trk_fname'], 'rb').read()
 
     def test_load_write_file(self):
         for fname in [DATA['empty_trk_fname'],
@@ -328,8 +330,7 @@ class TestTRK(unittest.TestCase):
         assert_tractogram_equal(new_trk.tractogram, new_trk_orig.tractogram)
 
         trk_file.seek(0, os.SEEK_SET)
-        assert_equal(trk_file.read(),
-                     open(DATA['standard_LPS_trk_fname'], 'rb').read())
+        assert trk_file.read() == open(DATA['standard_LPS_trk_fname'], 'rb').read()
 
         # Test writing a file where the header is missing the
         # Field.VOXEL_ORDER.
@@ -352,8 +353,7 @@ class TestTRK(unittest.TestCase):
         assert_tractogram_equal(new_trk.tractogram, new_trk_orig.tractogram)
 
         trk_file.seek(0, os.SEEK_SET)
-        assert_equal(trk_file.read(),
-                     open(DATA['standard_LPS_trk_fname'], 'rb').read())
+        assert trk_file.read() == open(DATA['standard_LPS_trk_fname'], 'rb').read()
 
     def test_write_optional_header_fields(self):
         # The TRK file format doesn't support additional header fields.
@@ -367,7 +367,7 @@ class TestTRK(unittest.TestCase):
         trk_file.seek(0, os.SEEK_SET)
 
         new_trk = TrkFile.load(trk_file)
-        assert_true("extra" not in new_trk.header)
+        assert "extra" not in new_trk.header
 
     def test_write_too_many_scalars_and_properties(self):
         # TRK supports up to 10 data_per_point.
@@ -395,7 +395,8 @@ class TestTRK(unittest.TestCase):
                                 affine_to_rasmm=np.eye(4))
 
         trk = TrkFile(tractogram)
-        assert_raises(ValueError, trk.save, BytesIO())
+        with pytest.raises(ValueError):
+            trk.save(BytesIO())
 
         # TRK supports up to 10 data_per_streamline.
         data_per_streamline = {}
@@ -421,7 +422,8 @@ class TestTRK(unittest.TestCase):
                                 data_per_streamline=data_per_streamline)
 
         trk = TrkFile(tractogram)
-        assert_raises(ValueError, trk.save, BytesIO())
+        with pytest.raises(ValueError):
+            trk.save(BytesIO())
 
     def test_write_scalars_and_properties_name_too_long(self):
         # TRK supports data_per_point name up to 20 characters.
@@ -437,7 +439,8 @@ class TestTRK(unittest.TestCase):
 
             trk = TrkFile(tractogram)
             if nb_chars > 18:
-                assert_raises(ValueError, trk.save, BytesIO())
+                with pytest.raises(ValueError):
+                    trk.save(BytesIO())
             else:
                 trk.save(BytesIO())
 
@@ -448,7 +451,8 @@ class TestTRK(unittest.TestCase):
 
             trk = TrkFile(tractogram)
             if nb_chars > 20:
-                assert_raises(ValueError, trk.save, BytesIO())
+                with pytest.raises(ValueError):
+                    trk.save(BytesIO())
             else:
                 trk.save(BytesIO())
 
@@ -465,7 +469,8 @@ class TestTRK(unittest.TestCase):
 
             trk = TrkFile(tractogram)
             if nb_chars > 18:
-                assert_raises(ValueError, trk.save, BytesIO())
+                with pytest.raises(ValueError):
+                    trk.save(BytesIO())
             else:
                 trk.save(BytesIO())
 
@@ -476,7 +481,8 @@ class TestTRK(unittest.TestCase):
 
             trk = TrkFile(tractogram)
             if nb_chars > 20:
-                assert_raises(ValueError, trk.save, BytesIO())
+                with pytest.raises(ValueError):
+                    trk.save(BytesIO())
             else:
                 trk.save(BytesIO())
 
@@ -498,32 +504,37 @@ class TestTRK(unittest.TestCase):
         hdr_from_fname['_offset_data'] += hdr_pos  # Correct for start position
         assert_arr_dict_equal(TrkFile._read_header(bio), hdr_from_fname)
         # Check fileobject file position has not changed
-        assert_equal(bio.tell(), hdr_pos)
+        assert bio.tell() == hdr_pos
 
 
 def test_encode_names():
     # Test function for encoding numbers into property names
     b0 = b'\x00'
-    assert_equal(encode_value_in_name(0, 'foo', 10),
-                 b'foo' + b0 * 7)
-    assert_equal(encode_value_in_name(1, 'foo', 10),
-                 b'foo' + b0 * 7)
-    assert_equal(encode_value_in_name(8, 'foo', 10),
-                 b'foo' + b0 + b'8' + b0 * 5)
-    assert_equal(encode_value_in_name(40, 'foobar', 10),
-                 b'foobar' + b0 + b'40' + b0)
-    assert_equal(encode_value_in_name(1, 'foobarbazz', 10), b'foobarbazz')
-    assert_raises(ValueError, encode_value_in_name, 1, 'foobarbazzz', 10)
-    assert_raises(ValueError, encode_value_in_name, 2, 'foobarbaz', 10)
-    assert_equal(encode_value_in_name(2, 'foobarba', 10), b'foobarba\x002')
+    assert encode_value_in_name(0, 'foo', 10) == b'foo' + b0 * 7
+    assert encode_value_in_name(1, 'foo', 10) == b'foo' + b0 * 7
+    assert encode_value_in_name(8, 'foo', 10) == b'foo' + b0 + b'8' + b0 * 5
+    assert encode_value_in_name(40, 'foobar', 10) == b'foobar' + b0 + b'40' + b0
+    assert encode_value_in_name(1, 'foobarbazz', 10) == b'foobarbazz'
+
+    with pytest.raises(ValueError):
+        encode_value_in_name(1, 'foobarbazzz', 10)
+
+    with pytest.raises(ValueError):
+        encode_value_in_name(2, 'foobarbazzz', 10)
+
+    assert encode_value_in_name(2, 'foobarba', 10) == b'foobarba\x002'
 
 
 def test_decode_names():
     # Test function for decoding name string into name, number
     b0 = b'\x00'
-    assert_equal(decode_value_from_name(b''), ('', 0))
-    assert_equal(decode_value_from_name(b'foo' + b0 * 7), ('foo', 1))
-    assert_equal(decode_value_from_name(b'foo\x008' + b0 * 5), ('foo', 8))
-    assert_equal(decode_value_from_name(b'foobar\x0010\x00'), ('foobar', 10))
-    assert_raises(ValueError, decode_value_from_name, b'foobar\x0010\x01')
-    assert_raises(HeaderError, decode_value_from_name, b'foo\x0010\x00111')
+    assert decode_value_from_name(b'') == ('', 0)
+    assert decode_value_from_name(b'foo' + b0 * 7) == ('foo', 1)
+    assert decode_value_from_name(b'foo\x008' + b0 * 5) == ('foo', 8)
+    assert decode_value_from_name(b'foobar\x0010\x00') == ('foobar', 10)
+
+    with pytest.raises(ValueError):
+        decode_value_from_name(b'foobar\x0010\x01')
+
+    with pytest.raises(HeaderError):
+        decode_value_from_name(b'foo\x0010\x00111')
