@@ -8,7 +8,6 @@
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """ Tests for arrayproxy module
 """
-from __future__ import division, print_function, absolute_import
 
 import warnings
 import gzip
@@ -24,12 +23,11 @@ from ..arrayproxy import (ArrayProxy, is_proxy, reshape_dataobj)
 from ..openers import ImageOpener
 from ..nifti1 import Nifti1Header
 
-import mock
+from unittest import mock
 
 from numpy.testing import assert_array_equal, assert_array_almost_equal
-from nose.tools import (assert_true, assert_false, assert_equal,
-                        assert_not_equal, assert_raises)
-from nibabel.testing import memmap_after_ufunc
+import pytest
+from ..testing import memmap_after_ufunc
 
 from .test_fileslice import slicer_samples
 from .test_openers import patch_indexed_gzip
@@ -68,28 +66,30 @@ def test_init():
     dtype = np.int32
     arr = np.arange(24, dtype=dtype).reshape(shape)
     bio.seek(16)
-    bio.write(arr.tostring(order='F'))
+    bio.write(arr.tobytes(order='F'))
     hdr = FunkyHeader(shape)
     ap = ArrayProxy(bio, hdr)
-    assert_true(ap.file_like is bio)
-    assert_equal(ap.shape, shape)
+    assert ap.file_like is bio
+    assert ap.shape == shape
     # shape should be read only
-    assert_raises(AttributeError, setattr, ap, 'shape', shape)
+    with pytest.raises(AttributeError):
+        ap.shape = shape
     # Get the data
     assert_array_equal(np.asarray(ap), arr)
     # Check we can modify the original header without changing the ap version
     hdr.shape[0] = 6
-    assert_not_equal(ap.shape, shape)
+    assert ap.shape != shape
     # Data stays the same, also
     assert_array_equal(np.asarray(ap), arr)
     # C order also possible
     bio = BytesIO()
     bio.seek(16)
-    bio.write(arr.tostring(order='C'))
+    bio.write(arr.tobytes(order='C'))
     ap = CArrayProxy(bio, FunkyHeader((2, 3, 4)))
     assert_array_equal(np.asarray(ap), arr)
     # Illegal init
-    assert_raises(TypeError, ArrayProxy, bio, object())
+    with pytest.raises(TypeError):
+        ArrayProxy(bio, object())
 
 
 def test_tuplespec():
@@ -98,7 +98,7 @@ def test_tuplespec():
     dtype = np.int32
     arr = np.arange(24, dtype=dtype).reshape(shape)
     bio.seek(16)
-    bio.write(arr.tostring(order='F'))
+    bio.write(arr.tobytes(order='F'))
     # Create equivalent header and tuple specs
     hdr = FunkyHeader(shape)
     tuple_spec = (hdr.get_data_shape(), hdr.get_data_dtype(),
@@ -107,29 +107,29 @@ def test_tuplespec():
     ap_tuple = ArrayProxy(bio, tuple_spec)
     # Header and tuple specs produce identical behavior
     for prop in ('shape', 'dtype', 'offset', 'slope', 'inter', 'is_proxy'):
-        assert_equal(getattr(ap_header, prop), getattr(ap_tuple, prop))
+        assert getattr(ap_header, prop) == getattr(ap_tuple, prop)
     for method, args in (('get_unscaled', ()), ('__array__', ()),
                          ('__getitem__', ((0, 2, 1), ))
                          ):
         assert_array_equal(getattr(ap_header, method)(*args),
                            getattr(ap_tuple, method)(*args))
-    # Tuple-defined ArrayProxies have no header to store
-    with warnings.catch_warnings():
-        assert_true(ap_tuple.header is None)
     # Partial tuples of length 2-4 are also valid
     for n in range(2, 5):
         ArrayProxy(bio, tuple_spec[:n])
     # Bad tuple lengths
-    assert_raises(TypeError, ArrayProxy, bio, ())
-    assert_raises(TypeError, ArrayProxy, bio, tuple_spec[:1])
-    assert_raises(TypeError, ArrayProxy, bio, tuple_spec + ('error',))
+    with pytest.raises(TypeError):
+        ArrayProxy(bio, ())
+    with pytest.raises(TypeError):
+        ArrayProxy(bio, tuple_spec[:1])
+    with pytest.raises(TypeError):
+        ArrayProxy(bio, tuple_spec + ('error',))
 
 
 def write_raw_data(arr, hdr, fileobj):
     hdr.set_data_shape(arr.shape)
     hdr.set_data_dtype(arr.dtype)
     fileobj.write(b'\x00' * hdr.get_data_offset())
-    fileobj.write(arr.tostring(order='F'))
+    fileobj.write(arr.tobytes(order='F'))
 
 
 def test_nifti1_init():
@@ -140,12 +140,8 @@ def test_nifti1_init():
     write_raw_data(arr, hdr, bio)
     hdr.set_slope_inter(2, 10)
     ap = ArrayProxy(bio, hdr)
-    assert_true(ap.file_like == bio)
-    assert_equal(ap.shape, shape)
-    # Check there has been a copy of the header
-    with warnings.catch_warnings():
-        warnings.simplefilter("ignore")
-        assert_false(ap.header is hdr)
+    assert ap.file_like == bio
+    assert ap.shape == shape
     # Get the data
     assert_array_equal(np.asarray(ap), arr * 2.0 + 10)
     with InTemporaryDirectory():
@@ -153,8 +149,8 @@ def test_nifti1_init():
         write_raw_data(arr, hdr, f)
         f.close()
         ap = ArrayProxy('test.nii', hdr)
-        assert_true(ap.file_like == 'test.nii')
-        assert_equal(ap.shape, shape)
+        assert ap.file_like == 'test.nii'
+        assert ap.shape == shape
         assert_array_equal(np.asarray(ap), arr * 2.0 + 10)
 
 
@@ -171,7 +167,7 @@ def test_proxy_slicing():
             for order, klass in ('F', ArrayProxy), ('C', CArrayProxy):
                 fobj = BytesIO()
                 fobj.write(b'\0' * offset)
-                fobj.write(arr.tostring(order=order))
+                fobj.write(arr.tobytes(order=order))
                 prox = klass(fobj, hdr)
                 for sliceobj in slicer_samples(shape):
                     assert_array_equal(arr[sliceobj], prox[sliceobj])
@@ -179,7 +175,7 @@ def test_proxy_slicing():
     hdr.set_slope_inter(2.0, 1.0)
     fobj = BytesIO()
     fobj.write(b'\0' * offset)
-    fobj.write(arr.tostring(order='F'))
+    fobj.write(arr.tobytes(order='F'))
     prox = ArrayProxy(fobj, hdr)
     sliceobj = (None, slice(None), 1, -1)
     assert_array_equal(arr[sliceobj] * 2.0 + 1.0, prox[sliceobj])
@@ -190,14 +186,14 @@ def test_is_proxy():
     hdr = FunkyHeader((2, 3, 4))
     bio = BytesIO()
     prox = ArrayProxy(bio, hdr)
-    assert_true(is_proxy(prox))
-    assert_false(is_proxy(bio))
-    assert_false(is_proxy(hdr))
-    assert_false(is_proxy(np.zeros((2, 3, 4))))
+    assert is_proxy(prox)
+    assert not is_proxy(bio)
+    assert not is_proxy(hdr)
+    assert not is_proxy(np.zeros((2, 3, 4)))
 
     class NP(object):
         is_proxy = False
-    assert_false(is_proxy(NP()))
+    assert not is_proxy(NP())
 
 
 def test_reshape_dataobj():
@@ -207,15 +203,15 @@ def test_reshape_dataobj():
     bio = BytesIO()
     prox = ArrayProxy(bio, hdr)
     arr = np.arange(np.prod(shape), dtype=prox.dtype).reshape(shape)
-    bio.write(b'\x00' * prox.offset + arr.tostring(order='F'))
+    bio.write(b'\x00' * prox.offset + arr.tobytes(order='F'))
     assert_array_equal(prox, arr)
     assert_array_equal(reshape_dataobj(prox, (2, 3, 4)),
                        np.reshape(arr, (2, 3, 4)))
-    assert_equal(prox.shape, shape)
-    assert_equal(arr.shape, shape)
+    assert prox.shape == shape
+    assert arr.shape == shape
     assert_array_equal(reshape_dataobj(arr, (2, 3, 4)),
                        np.reshape(arr, (2, 3, 4)))
-    assert_equal(arr.shape, shape)
+    assert arr.shape == shape
 
     class ArrGiver(object):
 
@@ -224,7 +220,7 @@ def test_reshape_dataobj():
 
     assert_array_equal(reshape_dataobj(ArrGiver(), (2, 3, 4)),
                        np.reshape(arr, (2, 3, 4)))
-    assert_equal(arr.shape, shape)
+    assert arr.shape == shape
 
 
 def test_reshaped_is_proxy():
@@ -232,13 +228,16 @@ def test_reshaped_is_proxy():
     hdr = FunkyHeader(shape)
     bio = BytesIO()
     prox = ArrayProxy(bio, hdr)
-    assert_true(isinstance(prox.reshape((2, 3, 4)), ArrayProxy))
+    assert isinstance(prox.reshape((2, 3, 4)), ArrayProxy)
     minus1 = prox.reshape((2, -1, 4))
-    assert_true(isinstance(minus1, ArrayProxy))
-    assert_equal(minus1.shape, (2, 3, 4))
-    assert_raises(ValueError, prox.reshape, (-1, -1, 4))
-    assert_raises(ValueError, prox.reshape, (2, 3, 5))
-    assert_raises(ValueError, prox.reshape, (2, -1, 5))
+    assert isinstance(minus1, ArrayProxy)
+    assert minus1.shape == (2, 3, 4)
+    with pytest.raises(ValueError):
+        prox.reshape((-1, -1, 4))
+    with pytest.raises(ValueError):
+        prox.reshape((2, 3, 5))
+    with pytest.raises(ValueError):
+        prox.reshape((2, -1, 5))
 
 
 def test_get_unscaled():
@@ -253,7 +252,7 @@ def test_get_unscaled():
     # Check standard read works
     arr = np.arange(24, dtype=np.int32).reshape(shape, order='F')
     bio.write(b'\x00' * hdr.get_data_offset())
-    bio.write(arr.tostring(order='F'))
+    bio.write(arr.tobytes(order='F'))
     prox = ArrayProxy(bio, hdr)
     assert_array_almost_equal(np.array(prox), arr * 2.1 + 3.14)
     # Check unscaled read works
@@ -302,7 +301,7 @@ def check_mmap(hdr, offset, proxy_class,
     with InTemporaryDirectory():
         with open(fname, 'wb') as fobj:
             fobj.write(b' ' * offset)
-            fobj.write(arr.tostring(order='F'))
+            fobj.write(arr.tobytes(order='F'))
         for mmap, expected_mode in (
                 # mmap value, expected memmap mode
                 # mmap=None -> no mmap value
@@ -321,21 +320,22 @@ def check_mmap(hdr, offset, proxy_class,
             unscaled_is_mmap = isinstance(unscaled, np.memmap)
             back_is_mmap =  isinstance(back_data, np.memmap)
             if expected_mode is None:
-                assert_false(unscaled_is_mmap)
-                assert_false(back_is_mmap)
+                assert not unscaled_is_mmap
+                assert not back_is_mmap
             else:
-                assert_equal(unscaled_is_mmap,
-                             viral_memmap or unscaled_really_mmap)
-                assert_equal(back_is_mmap,
-                             viral_memmap or scaled_really_mmap)
+                assert unscaled_is_mmap == (viral_memmap or unscaled_really_mmap)
+                assert back_is_mmap == (viral_memmap or scaled_really_mmap)
                 if scaled_really_mmap:
-                    assert_equal(back_data.mode, expected_mode)
+                    assert back_data.mode == expected_mode
             del prox, back_data
             # Check that mmap is keyword-only
-            assert_raises(TypeError, proxy_class, fname, hdr, True)
+            with pytest.raises(TypeError):
+                proxy_class(fname, hdr, True)
             # Check invalid values raise error
-            assert_raises(ValueError, proxy_class, fname, hdr, mmap='rw')
-            assert_raises(ValueError, proxy_class, fname, hdr, mmap='r+')
+            with pytest.raises(ValueError):
+                proxy_class(fname, hdr, mmap='rw')
+            with pytest.raises(ValueError):
+                proxy_class(fname, hdr, mmap='r+')
 
 
 # An image opener class which counts how many instances of itself have been
@@ -373,8 +373,6 @@ def test_keep_file_open_true_false_invalid():
     # False     | True             | True                | True
     # True      | False            | True                | n/a
     # True      | True             | True                | False
-    # 'auto'    | False            | False               | n/a
-    # 'auto'    | True             | True                | False
     #
     # Each test tuple contains:
     #  - file type - gzipped ('gz') or not ('bin'), or an open file handle
@@ -389,26 +387,18 @@ def test_keep_file_open_true_false_invalid():
         ('open', False,  True,  False, False),
         ('open', True,   False, False, False),
         ('open', True,   True,  False, False),
-        ('open', 'auto', False, False, False),
-        ('open', 'auto', True,  False, False),
         # non-gzip file - have_igzip is irrelevant, decision should be made
         # solely from kfo flag
         ('bin', False,  False, False, False),
         ('bin', False,  True,  False, False),
         ('bin', True,   False, True,  True),
         ('bin', True,   True,  True,  True),
-        ('bin', 'auto', False, False, False),
-        ('bin', 'auto', True,  False, False),
-        # gzip file. If igzip is present, we persist the ImageOpener. If kfo
-        # is 'auto':
-        #  - if igzip is present, kfo -> True
-        #  - otherwise, kfo -> False
+        # gzip file. If igzip is present, we persist the ImageOpener.
         ('gz', False,  False, False, False),
         ('gz', False,  True,  True,  False),
         ('gz', True,   False, True,  True),
         ('gz', True,   True,  True,  True),
-        ('gz', 'auto', False, False, False),
-        ('gz', 'auto', True,  True,  True)]
+        ]
 
     dtype = np.float32
     data  = np.arange(1000, dtype=dtype).reshape((10, 10, 10))
@@ -423,10 +413,10 @@ def test_keep_file_open_true_false_invalid():
             # create the test data file
             if filetype == 'gz':
                 with gzip.open(fname, 'wb') as fobj:
-                    fobj.write(data.tostring(order='F'))
+                    fobj.write(data.tobytes(order='F'))
             else:
                 with open(fname, 'wb') as fobj:
-                    fobj.write(data.tostring(order='F'))
+                    fobj.write(data.tobytes(order='F'))
             # pass in a file name or open file handle. If the latter, we open
             # two file handles, because we're going to create two proxies
             # below.
@@ -477,13 +467,15 @@ def test_keep_file_open_true_false_invalid():
     with InTemporaryDirectory():
         fname = 'testdata'
         with open(fname, 'wb') as fobj:
-            fobj.write(data.tostring(order='F'))
-        with assert_raises(ValueError):
-            ArrayProxy(fname, ((10, 10, 10), dtype), keep_file_open=55)
-        with assert_raises(ValueError):
-            ArrayProxy(fname, ((10, 10, 10), dtype), keep_file_open='autob')
-        with assert_raises(ValueError):
-            ArrayProxy(fname, ((10, 10, 10), dtype), keep_file_open='cauto')
+            fobj.write(data.tobytes(order='F'))
+
+        for invalid_kfo in (55, 'auto', 'cauto'):
+            with pytest.raises(ValueError):
+                ArrayProxy(fname, ((10, 10, 10), dtype),
+                           keep_file_open=invalid_kfo)
+            with patch_keep_file_open_default(invalid_kfo):
+                with pytest.raises(ValueError):
+                    ArrayProxy(fname, ((10, 10, 10), dtype))
 
 
 def test_pickle_lock():
