@@ -15,9 +15,7 @@ import logging
 
 from ..batteryrunners import BatteryRunner, Report
 
-from ..testing import (assert_true, assert_false, assert_equal,
-                       assert_not_equal, assert_raises)
-
+import pytest
 
 # define some trivial functions as checks
 def chk1(obj, fix=False):
@@ -80,64 +78,67 @@ def chk_error(obj, fix=False):
 
 def test_init_basic():
     # With no args, raise
-    assert_raises(TypeError, BatteryRunner)
+    with pytest.raises(TypeError):
+        BatteryRunner()
     # Len returns number of checks
     battrun = BatteryRunner((chk1,))
-    assert_equal(len(battrun), 1)
+    assert len(battrun) == 1
     battrun = BatteryRunner((chk1, chk2))
-    assert_equal(len(battrun), 2)
+    assert len(battrun) == 2
 
 
 def test_init_report():
     rep = Report()
-    assert_equal(rep, Report(Exception, 0, '', ''))
+    assert rep == Report(Exception, 0, '', '')
 
 
 def test_report_strings():
     rep = Report()
-    assert_not_equal(rep.__str__(), '')
-    assert_equal(rep.message, '')
+    assert rep.__str__() != ''
+    assert rep.message == ''
     str_io = StringIO()
     rep.write_raise(str_io)
-    assert_equal(str_io.getvalue(), '')
+    assert str_io.getvalue() == ''
     rep = Report(ValueError, 20, 'msg', 'fix')
     rep.write_raise(str_io)
-    assert_equal(str_io.getvalue(), '')
+    assert str_io.getvalue() == ''
     rep.problem_level = 30
     rep.write_raise(str_io)
-    assert_equal(str_io.getvalue(), 'Level 30: msg; fix\n')
+    assert str_io.getvalue() == 'Level 30: msg; fix\n'
     str_io.truncate(0)
     str_io.seek(0)
     # No fix string, no fix message
     rep.fix_msg = ''
     rep.write_raise(str_io)
-    assert_equal(str_io.getvalue(), 'Level 30: msg\n')
+    assert str_io.getvalue() == 'Level 30: msg\n'
     rep.fix_msg = 'fix'
     str_io.truncate(0)
     str_io.seek(0)
     # If we drop the level, nothing goes to the log
     rep.problem_level = 20
     rep.write_raise(str_io)
-    assert_equal(str_io.getvalue(), '')
+    assert str_io.getvalue() == ''
     # Unless we set the default log level in the call
     rep.write_raise(str_io, log_level=20)
-    assert_equal(str_io.getvalue(), 'Level 20: msg; fix\n')
+    assert str_io.getvalue() == 'Level 20: msg; fix\n'
     str_io.truncate(0)
     str_io.seek(0)
     # If we set the error level down this low, we raise an error
-    assert_raises(ValueError, rep.write_raise, str_io, 20)
+    with pytest.raises(ValueError):
+        rep.write_raise(str_io, 20)
     # But the log level wasn't low enough to do a log entry
-    assert_equal(str_io.getvalue(), '')
+    assert str_io.getvalue() == ''
     # Error still raised with lower log threshold, but now we do get a
     # log entry
-    assert_raises(ValueError, rep.write_raise, str_io, 20, 20)
-    assert_equal(str_io.getvalue(), 'Level 20: msg; fix\n')
+    with pytest.raises(ValueError):
+        rep.write_raise(str_io, 20, 20)
+    assert str_io.getvalue() == 'Level 20: msg; fix\n'
     # If there's no error, we can't raise
     str_io.truncate(0)
     str_io.seek(0)
     rep.error = None
     rep.write_raise(str_io, 20)
-    assert_equal(str_io.getvalue(), '')
+    assert str_io.getvalue() == ''
 
 
 def test_logging():
@@ -147,10 +148,10 @@ def test_logging():
     logger.setLevel(30)  # defaultish level
     logger.addHandler(logging.StreamHandler(str_io))
     rep.log_raise(logger)
-    assert_equal(str_io.getvalue(), '')
+    assert str_io.getvalue() == ''
     rep.problem_level = 30
     rep.log_raise(logger)
-    assert_equal(str_io.getvalue(), 'msg; fix\n')
+    assert str_io.getvalue() == 'msg; fix\n'
     str_io.truncate(0)
     str_io.seek(0)
 
@@ -158,43 +159,19 @@ def test_logging():
 def test_checks():
     battrun = BatteryRunner((chk1,))
     reports = battrun.check_only({})
-    assert_equal(reports[0],
-                 Report(KeyError,
-                        20,
-                        'no "testkey"',
-                        ''))
+    assert reports[0] == Report(KeyError, 20, 'no "testkey"', '')
     obj, reports = battrun.check_fix({})
-    assert_equal(reports[0],
-                 Report(KeyError,
-                        20,
-                        'no "testkey"',
-                        'added "testkey"'))
-    assert_equal(obj, {'testkey': 1})
+    assert reports[0] == Report(KeyError, 20, 'no "testkey"', 'added "testkey"')
+    assert obj == {'testkey': 1}
     battrun = BatteryRunner((chk1, chk2))
     reports = battrun.check_only({})
-    assert_equal(reports[0],
-                 Report(KeyError,
-                        20,
-                        'no "testkey"',
-                        ''))
-    assert_equal(reports[1],
-                 Report(KeyError,
-                        20,
-                        'no "testkey"',
-                        ''))
+    assert reports[0] == Report(KeyError, 20, 'no "testkey"', '')
+    assert reports[1] == Report(KeyError, 20, 'no "testkey"', '')
     obj, reports = battrun.check_fix({})
     # In the case of fix, the previous fix exposes a different error
     # Note, because obj is mutable, first and second point to modified
     # (and final) dictionary
     output_obj = {'testkey': 0}
-    assert_equal(reports[0],
-                 Report(KeyError,
-                        20,
-                        'no "testkey"',
-                        'added "testkey"'))
-    assert_equal(reports[1],
-                 Report(ValueError,
-                        10,
-                        '"testkey" != 0',
-                        'set "testkey" to 0'))
-    assert_equal(obj, output_obj)
+    assert reports[0] == Report(KeyError, 20, 'no "testkey"', 'added "testkey"')
+    assert reports[1] == Report(ValueError, 10, '"testkey" != 0', 'set "testkey" to 0')
+    assert obj == output_obj
