@@ -15,7 +15,6 @@ from .._h5py_compat import have_h5py
 from nibabel import imageclasses
 from nibabel.imageclasses import spatial_axes_first, class_map, ext_map
 
-from nose.tools import (assert_true, assert_false, assert_equal)
 
 from nibabel.testing import clear_and_catch_warnings
 
@@ -37,26 +36,26 @@ def test_spatial_axes_first():
         for img_class in (AnalyzeImage, Nifti1Image, Nifti2Image):
             data = np.zeros(shape)
             img = img_class(data, affine)
-            assert_true(spatial_axes_first(img))
+            assert spatial_axes_first(img)
     # True for MINC images < 4D
     for fname in MINC_3DS:
         img = nib.load(pjoin(DATA_DIR, fname))
-        assert_true(len(img.shape) == 3)
-        assert_true(spatial_axes_first(img))
+        assert len(img.shape) == 3
+        assert spatial_axes_first(img)
     # False for MINC images < 4D
     for fname in MINC_4DS:
         img = nib.load(pjoin(DATA_DIR, fname))
-        assert_true(len(img.shape) == 4)
-        assert_false(spatial_axes_first(img))
+        assert len(img.shape) == 4
+        assert not spatial_axes_first(img)
 
 
 def test_deprecations():
     with clear_and_catch_warnings(modules=[imageclasses]) as w:
         warnings.filterwarnings('always', category=DeprecationWarning)
         nifti_single = class_map['nifti_single']
-        assert_equal(nifti_single['class'], Nifti1Image)
-        assert_equal(len(w), 1)
+        assert nifti_single['class'] == Nifti1Image
+        assert len(w) == 1
         nifti_ext = ext_map['.nii']
-        assert_equal(nifti_ext, 'nifti_single')
-        assert_equal(len(w), 2)
+        assert nifti_ext == 'nifti_single'
+        assert len(w) == 2
 
