@@ -6,7 +6,6 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-from __future__ import division, print_function, absolute_import
 
 from os.path import join as pjoin
 
@@ -25,12 +24,13 @@ from .. import minc1
 from ..minc1 import Minc1File, Minc1Image, MincHeader
 
 from ..tmpdirs import InTemporaryDirectory
-from ..testing import (assert_true, assert_equal, assert_false, assert_raises, assert_warns,
-                       assert_array_equal, data_path, clear_and_catch_warnings)
+from ..deprecator import ExpiredDeprecationError
+from ..testing import assert_data_similar, data_path, clear_and_catch_warnings
+from numpy.testing import assert_array_equal
+import pytest
 
 from . import test_spatialimages as tsi
 from .test_fileslice import slicer_samples
-from .test_helpers import assert_data_similar
 
 EG_FNAME = pjoin(data_path, 'tiny.mnc')
 
@@ -105,46 +105,16 @@ def test_old_namespace():
     # Check warnings raised
     arr = np.arange(24).reshape((2, 3, 4))
     aff = np.diag([2, 3, 4, 1])
-    with clear_and_catch_warnings() as warns:
-        warnings.simplefilter('always', DeprecationWarning)
-        # Top level import.
-        # This import does not trigger an import of the minc.py module, because
-        # it's the proxy object.
-        from .. import minc
-        assert_equal(warns, [])
-        # If there was a previous import it will be module, otherwise it will be
-        # a proxy
-        previous_import = isinstance(minc, types.ModuleType)
-        if not previous_import:
-            assert_true(isinstance(minc, ModuleProxy))
-        old_minc1image = minc.Minc1Image  # just to check it works
-        # There may or may not be a warning raised on accessing the proxy,
-        # depending on whether the minc.py module is already imported in this
-        # test run.
-        if not previous_import:
-            assert_equal(warns.pop(0).category, DeprecationWarning)
 
-    with clear_and_catch_warnings() as warns:
-        from .. import Minc1Image, MincImage
-        assert_equal(warns, [])
-        # The import from old module is the same as that from new
-        assert_true(old_minc1image is Minc1Image)
-        # But the old named import, imported from new, is not the same
-        assert_false(Minc1Image is MincImage)
-        assert_equal(warns, [])
-        # Create object using old name
-        mimg = MincImage(arr, aff)
-        # Call to create object created warning
-        assert_equal(warns.pop(0).category, FutureWarning)
-        assert_array_equal(mimg.get_data(), arr)
-        # Another old name
-        from ..minc1 import MincFile, Minc1File
-        assert_false(MincFile is Minc1File)
-        assert_equal(warns, [])
+    from .. import Minc1Image, MincImage
+    assert Minc1Image is not MincImage
+    with pytest.raises(ExpiredDeprecationError):
+        MincImage(arr, aff)
+    # Another old name
+    from ..minc1 import MincFile, Minc1File
+    assert MincFile is not Minc1File
+    with pytest.raises(ExpiredDeprecationError):
         mf = MincFile(netcdf_file(EG_FNAME))
-        # Call to create object created warning
-        assert_equal(warns.pop(0).category, FutureWarning)
-        assert_equal(mf.get_data_shape(), (10, 20, 20))
 
 
 class _TestMincFile(object):
@@ -158,12 +128,12 @@ class _TestMincFile(object):
         for tp in self.test_files:
             mnc_obj = self.opener(tp['fname'], 'r')
             mnc = self.file_class(mnc_obj)
-            assert_equal(mnc.get_data_dtype().type, tp['dtype'])
-            assert_equal(mnc.get_data_shape(), tp['shape'])
-            assert_equal(mnc.get_zooms(), tp['zooms'])
+            assert mnc.get_data_dtype().type == tp['dtype']
+            assert mnc.get_data_shape() == tp['shape']
+            assert mnc.get_zooms() == tp['zooms']
             assert_array_equal(mnc.get_affine(), tp['affine'])
             data = mnc.get_scaled_data()
-            assert_equal(data.shape, tp['shape'])
+            assert data.shape == tp['shape']
 
     def test_mincfile_slicing(self):
         # Test slicing and scaling of mincfile data
@@ -186,22 +156,22 @@ class _TestMincFile(object):
         # Check highest level load of minc works
         for tp in self.test_files:
             img = load(tp['fname'])
-            data = img.get_data()
-            assert_equal(data.shape, tp['shape'])
+            data = img.get_fdata()
+            assert data.shape == tp['shape']
             # min, max, mean values from read in SPM2 / minctools
             assert_data_similar(data, tp)
             # check if mnc can be converted to nifti
             ni_img = Nifti1Image.from_image(img)
             assert_array_equal(ni_img.affine, tp['affine'])
-            assert_array_equal(ni_img.get_data(), data)
+            assert_array_equal(ni_img.get_fdata(), data)
 
     def test_array_proxy_slicing(self):
         # Test slicing of array proxy
         for tp in self.test_files:
             img = load(tp['fname'])
-            arr = img.get_data()
+            arr = img.get_fdata()
             prox = img.dataobj
-            assert_true(prox.is_proxy)
+            assert prox.is_proxy
             for sliceobj in slicer_samples(img.shape):
                 assert_array_equal(arr[sliceobj], prox[sliceobj])
 
@@ -221,7 +191,7 @@ class TestMinc1File(_TestMincFile):
                     fobj.write(content)
                     fobj.close()
                     img = self.module.load(fname)
-                    data = img.get_data()
+                    data = img.get_fdata()
                     assert_data_similar(data, tp)
                     del img
 
@@ -231,8 +201,10 @@ def test_header_data_io():
     bio = BytesIO()
     hdr = MincHeader()
     arr = np.arange(24).reshape((2, 3, 4))
-    assert_raises(NotImplementedError, hdr.data_to_fileobj, arr, bio)
-    assert_raises(NotImplementedError, hdr.data_from_fileobj, bio)
+    with pytest.raises(NotImplementedError):
+        hdr.data_to_fileobj(arr, bio)
+    with pytest.raises(NotImplementedError):
+        hdr.data_from_fileobj(bio)
 
 
 class TestMinc1Image(tsi.TestSpatialImage):
@@ -246,7 +218,7 @@ class TestMinc1Image(tsi.TestSpatialImage):
             img = self.module.load(fpath)
             bio = BytesIO()
             arr = np.arange(24).reshape((2, 3, 4))
-            assert_raises(NotImplementedError,
-                          img.header.data_to_fileobj, arr, bio)
-            assert_raises(NotImplementedError,
-                          img.header.data_from_fileobj, bio)
+            with pytest.raises(NotImplementedError):
+                img.header.data_to_fileobj(arr, bio)
+            with pytest.raises(NotImplementedError):
+                img.header.data_from_fileobj(bio)
