@@ -20,10 +20,9 @@ from ..tmpdirs import InTemporaryDirectory
 from ..loadsave import load
 from ..orientations import flip_axis, aff2axcodes, inv_ornt_aff
 
-from nose.tools import assert_true, assert_false, assert_equal
-from nose import SkipTest
-
-from numpy.testing import assert_almost_equal, assert_array_equal
+import unittest
+import pytest
+from numpy.testing import assert_almost_equal
 
 from .scriptrunner import ScriptRunner
 from .nibabel_data import needs_nibabel_data
@@ -31,7 +30,7 @@ from ..testing import assert_dt_equal, assert_re_in
 from .test_parrec import (DTI_PAR_BVECS, DTI_PAR_BVALS,
                           EXAMPLE_IMAGES as PARREC_EXAMPLES)
 from .test_parrec_data import BALLS, AFF_OFF
-from .test_helpers import assert_data_similar
+from ..testing import assert_data_similar
 
 
 def _proc_stdout(stdout):
@@ -55,6 +54,14 @@ script_test.__test__ = False  # It's not a test
 DATA_PATH = abspath(pjoin(dirname(__file__), 'data'))
 
 
+def load_small_file():
+    try:
+        load(pjoin(DATA_PATH, 'small.mnc'))
+        return True
+    except:
+        return False
+
+
 def check_nib_ls_example4d(opts=[], hdrs_str="", other_str=""):
     # test nib-ls script
     fname = pjoin(DATA_PATH, 'example4d.nii.gz')
@@ -63,7 +70,7 @@ def check_nib_ls_example4d(opts=[], hdrs_str="", other_str=""):
                    % (hdrs_str, other_str))
     cmd = ['nib-ls'] + opts + [fname]
     code, stdout, stderr = run_command(cmd)
-    assert_equal(fname, stdout[:len(fname)])
+    assert fname == stdout[:len(fname)]
     assert_re_in(expected_re, stdout[len(fname):])
 
 
@@ -76,45 +83,45 @@ def check_nib_diff_examples():
                       "quatern_c", "quatern_d", "qoffset_x", "qoffset_y", "qoffset_z", "srow_x",
                       "srow_y", "srow_z", "DATA(md5)", "DATA(diff 1:)"]
     for item in checked_fields:
-        assert_true(item in stdout)
+        assert item in stdout
 
     fnames2 = [pjoin(DATA_PATH, f)
               for f in ('example4d.nii.gz', 'example4d.nii.gz')]
     code, stdout, stderr = run_command(['nib-diff'] + fnames2, check_code=False)
-    assert_equal(stdout, "These files are identical.")
+    assert stdout == "These files are identical."
 
     fnames3 = [pjoin(DATA_PATH, f)
                for f in ('standard.nii.gz', 'example4d.nii.gz', 'example_nifti2.nii.gz')]
     code, stdout, stderr = run_command(['nib-diff'] + fnames3, check_code=False)
     for item in checked_fields:
-        assert_true(item in stdout)
+        assert item in stdout
 
     fnames4 = [pjoin(DATA_PATH, f)
                for f in ('standard.nii.gz', 'standard.nii.gz', 'standard.nii.gz')]
     code, stdout, stderr = run_command(['nib-diff'] + fnames4, check_code=False)
-    assert_equal(stdout, "These files are identical.")
+    assert stdout == "These files are identical."
 
     code, stdout, stderr = run_command(['nib-diff', '--dt', 'float64'] + fnames, check_code=False)
     for item in checked_fields:
-        assert_true(item in stdout)
+        assert item in stdout
 
 
-
-@script_test
-def test_nib_ls():
-    yield check_nib_ls_example4d
-    yield check_nib_ls_example4d, \
-        ['-H', 'dim,bitpix'], " \[  4 128  96  24   2   1   1   1\] 16"
-    yield check_nib_ls_example4d, ['-c'], "", " !1030 uniques. Use --all-counts"
-    yield check_nib_ls_example4d, ['-c', '--all-counts'], "", " 2:3 3:2 4:1 5:1.*"
+@pytest.mark.parametrize("args", [
+    [],
+    [['-H', 'dim,bitpix'], " \[  4 128  96  24   2   1   1   1\] 16"],
+    [['-c'], "", " !1030 uniques. Use --all-counts"],
+    [['-c', '--all-counts'], "", " 2:3 3:2 4:1 5:1.*"],
     # both stats and counts
-    yield check_nib_ls_example4d, \
-        ['-c', '-s', '--all-counts'], "", " \[229725\] \[2, 1.2e\+03\] 2:3 3:2 4:1 5:1.*"
+    [['-c', '-s', '--all-counts'], "", " \[229725\] \[2, 1.2e\+03\] 2:3 3:2 4:1 5:1.*"],
     # and must not error out if we allow for zeros
-    yield check_nib_ls_example4d, \
-        ['-c', '-s', '-z', '--all-counts'], "", " \[589824\] \[0, 1.2e\+03\] 0:360099 2:3 3:2 4:1 5:1.*"
+    [['-c', '-s', '-z', '--all-counts'], "", " \[589824\] \[0, 1.2e\+03\] 0:360099 2:3 3:2 4:1 5:1.*"],
+])
+@script_test
+def test_nib_ls(args):
+    check_nib_ls_example4d(*args)
 
 
+@unittest.skipUnless(load_small_file(), "Can't load the small.mnc file")
 @script_test
 def test_nib_ls_multiple():
     # verify that correctly lists/formats for multiple files
@@ -125,42 +132,35 @@ def test_nib_ls_multiple():
     ]
     code, stdout, stderr = run_command(['nib-ls'] + fnames)
     stdout_lines = stdout.split('\n')
-    assert_equal(len(stdout_lines), 4)
-    try:
-        load(pjoin(DATA_PATH, 'small.mnc'))
-    except:
-        raise SkipTest("For the other tests should be able to load MINC files")
+    assert len(stdout_lines) == 4
 
     # they should be indented correctly.  Since all files are int type -
     ln = max(len(f) for f in fnames)
     i_str = ' i' if sys.byteorder == 'little' else ' <i'
-    assert_equal([l[ln:ln + len(i_str)] for l in stdout_lines], [i_str] * 4,
-          msg="Type sub-string didn't start with '%s'. "
+    assert ([l[ln:ln + len(i_str)] for l in stdout_lines] == [i_str] * 4, "Type sub-string didn't start with '%s'. "
               "Full output was: %s" % (i_str, stdout_lines))
     # and if disregard type indicator which might vary
-    assert_equal(
-        [l[l.index('['):] for l in stdout_lines],
+    assert (
+        [l[l.index('['):] for l in stdout_lines] ==
         [
             '[128,  96,  24,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform',
             '[ 32,  20,  12,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform',
             '[ 18,  28,  29]      9.00x8.00x7.00',
             '[ 91, 109,  91]      2.00x2.00x2.00'
-        ]
-    )
+        ])
 
     # Now run with -s for stats
     code, stdout, stderr = run_command(['nib-ls', '-s'] + fnames)
     stdout_lines = stdout.split('\n')
-    assert_equal(len(stdout_lines), 4)
-    assert_equal(
-        [l[l.index('['):] for l in stdout_lines],
+    assert len(stdout_lines) == 4
+    assert (
+        [l[l.index('['):] for l in stdout_lines] ==
         [
             '[128,  96,  24,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform [229725] [2, 1.2e+03]',
             '[ 32,  20,  12,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform [15360]  [46, 7.6e+02]',
             '[ 18,  28,  29]      9.00x8.00x7.00                         [14616]  [0.12, 93]',
             '[ 91, 109,  91]      2.00x2.00x2.00                          !error'
-        ]
-    )
+        ])
 
 
 @script_test
@@ -174,18 +174,18 @@ def test_help():
             except Exception:
                 continue  # do not test this one
         code, stdout, stderr = run_command([cmd, '--help'])
-        assert_equal(code, 0)
+        assert code == 0
         assert_re_in(".*%s" % cmd, stdout)
         assert_re_in(".*Usage", stdout)
         # Some third party modules might like to announce some Deprecation
         # etc warnings, see e.g. https://travis-ci.org/nipy/nibabel/jobs/370353602
         if 'warning' not in stderr.lower():
-            assert_equal(stderr, '')
+            assert stderr == ''
 
 
 @script_test
 def test_nib_diff():
-    yield check_nib_diff_examples
+    check_nib_diff_examples()
 
 
 @script_test
@@ -194,7 +194,7 @@ def test_nib_nifti_dx():
     clean_hdr = pjoin(DATA_PATH, 'nifti1.hdr')
     cmd = ['nib-nifti-dx', clean_hdr]
     code, stdout, stderr = run_command(cmd)
-    assert_equal(stdout.strip(), 'Header for "%s" is clean' % clean_hdr)
+    assert stdout.strip() == 'Header for "%s" is clean' % clean_hdr
     dirty_hdr = pjoin(DATA_PATH, 'analyze.hdr')
     cmd = ['nib-nifti-dx', dirty_hdr]
     code, stdout, stderr = run_command(cmd)
@@ -204,7 +204,7 @@ pixdim[0] (qfac) should be 1 (default) or -1
 magic string "" is not valid
 sform_code 11776 not valid""" % (dirty_hdr,)
     # Split strings to remove line endings
-    assert_equal(stdout, expected)
+    assert stdout == expected
 
 
 def vox_size(affine):
@@ -215,33 +215,33 @@ def check_conversion(cmd, pr_data, out_fname):
     run_command(cmd)
     img = load(out_fname)
     # Check orientations always LAS
-    assert_equal(aff2axcodes(img.affine), tuple('LAS'))
+    assert aff2axcodes(img.affine) == tuple('LAS')
     data = img.get_fdata()
-    assert_true(np.allclose(data, pr_data))
-    assert_true(np.allclose(img.header['cal_min'], data.min()))
-    assert_true(np.allclose(img.header['cal_max'], data.max()))
+    assert np.allclose(data, pr_data)
+    assert np.allclose(img.header['cal_min'], data.min())
+    assert np.allclose(img.header['cal_max'], data.max())
     del img, data  # for windows to be able to later delete the file
     # Check minmax options
     run_command(cmd + ['--minmax', '1', '2'])
     img = load(out_fname)
     data = img.get_fdata()
-    assert_true(np.allclose(data, pr_data))
-    assert_true(np.allclose(img.header['cal_min'], 1))
-    assert_true(np.allclose(img.header['cal_max'], 2))
+    assert np.allclose(data, pr_data)
+    assert np.allclose(img.header['cal_min'], 1)
+    assert np.allclose(img.header['cal_max'], 2)
     del img, data  # for windows
     run_command(cmd + ['--minmax', 'parse', '2'])
     img = load(out_fname)
     data = img.get_fdata()
-    assert_true(np.allclose(data, pr_data))
-    assert_true(np.allclose(img.header['cal_min'], data.min()))
-    assert_true(np.allclose(img.header['cal_max'], 2))
+    assert np.allclose(data, pr_data)
+    assert np.allclose(img.header['cal_min'], data.min())
+    assert np.allclose(img.header['cal_max'], 2)
     del img, data  # for windows
     run_command(cmd + ['--minmax', '1', 'parse'])
     img = load(out_fname)
     data = img.get_fdata()
-    assert_true(np.allclose(data, pr_data))
-    assert_true(np.allclose(img.header['cal_min'], 1))
-    assert_true(np.allclose(img.header['cal_max'], data.max()))
+    assert np.allclose(data, pr_data)
+    assert np.allclose(img.header['cal_min'], 1)
+    assert np.allclose(img.header['cal_max'], data.max())
     del img, data
 
 
@@ -250,27 +250,27 @@ def test_parrec2nii():
     # Test parrec2nii script
     cmd = ['parrec2nii', '--help']
     code, stdout, stderr = run_command(cmd)
-    assert_true(stdout.startswith('Usage'))
+    assert stdout.startswith('Usage')
     with InTemporaryDirectory():
         for eg_dict in PARREC_EXAMPLES:
             fname = eg_dict['fname']
             run_command(['parrec2nii', fname])
             out_froot = splitext(basename(fname))[0] + '.nii'
             img = load(out_froot)
-            assert_equal(img.shape, eg_dict['shape'])
+            assert img.shape == eg_dict['shape']
             assert_dt_equal(img.get_data_dtype(), eg_dict['dtype'])
             # Check against values from Philips converted nifti image
             data = img.get_fdata()
             assert_data_similar(data, eg_dict)
             assert_almost_equal(img.header.get_zooms(), eg_dict['zooms'])
             # Standard save does not save extensions
-            assert_equal(len(img.header.extensions), 0)
+            assert len(img.header.extensions) == 0
             # Delete previous img, data to make Windows happier
             del img, data
             # Does not overwrite unless option given
             code, stdout, stderr = run_command(
                 ['parrec2nii', fname], check_code=False)
-            assert_equal(code, 1)
+            assert code == 1
             # Default scaling is dv
             pr_img = load(fname)
             flipped_data = flip_axis(pr_img.get_fdata(), 1)
@@ -293,7 +293,7 @@ def test_parrec2nii():
             # Save extensions
             run_command(base_cmd + ['--store-header'])
             img = load(out_froot)
-            assert_equal(len(img.header.extensions), 1)
+            assert len(img.header.extensions) == 1
             del img  # To help windows delete the file
 
 
@@ -314,15 +314,15 @@ def test_parrec2nii_with_data():
             run_command(['parrec2nii', par])
             conved_img = load(par_root + '.nii')
             # Confirm parrec2nii conversions are LAS
-            assert_equal(aff2axcodes(conved_img.affine), tuple('LAS'))
+            assert aff2axcodes(conved_img.affine) == tuple('LAS')
             # Shape same whether LPS or LAS
-            assert_equal(conved_img.shape[:3], (80, 80, 10))
+            assert conved_img.shape[:3] == (80, 80, 10)
             # Test against original converted NIfTI
             nifti_fname = pjoin(BALLS, 'NIFTI', par_root + '.nii.gz')
             if exists(nifti_fname):
                 philips_img = load(nifti_fname)
                 # Confirm Philips converted image always LPS
-                assert_equal(aff2axcodes(philips_img.affine), tuple('LPS'))
+                assert aff2axcodes(philips_img.affine) == tuple('LPS')
                 # Equivalent to Philips LPS affine
                 equiv_affine = conved_img.affine.dot(LAS2LPS)
                 assert_almost_equal(philips_img.affine[:3, :3],
@@ -332,23 +332,22 @@ def test_parrec2nii_with_data():
                 assert_almost_equal(aff_off, AFF_OFF, 3)
                 # The difference is max in the order of 0.5 voxel
                 vox_sizes = vox_size(philips_img.affine)
-                assert_true(np.all(np.abs(aff_off / vox_sizes) <= 0.501))
+                assert np.all(np.abs(aff_off / vox_sizes) <= 0.501)
                 # The data is very close, unless it's the fieldmap
                 if par_root != 'fieldmap':
                     conved_data_lps = flip_axis(conved_img.dataobj, 1)
-                    assert_true(np.allclose(conved_data_lps,
-                                            philips_img.dataobj))
+                    assert np.allclose(conved_data_lps, philips_img.dataobj)
     with InTemporaryDirectory():
         # Test some options
         dti_par = pjoin(BALLS, 'PARREC', 'DTI.PAR')
         run_command(['parrec2nii', dti_par])
-        assert_true(exists('DTI.nii'))
-        assert_false(exists('DTI.bvals'))
-        assert_false(exists('DTI.bvecs'))
+        assert exists('DTI.nii')
+        assert not exists('DTI.bvals')
+        assert not exists('DTI.bvecs')
         # Does not overwrite unless option given
         code, stdout, stderr = run_command(['parrec2nii', dti_par],
                                            check_code=False)
-        assert_equal(code, 1)
+        assert code == 1
         # Writes bvals, bvecs files if asked
         run_command(['parrec2nii', '--overwrite', '--keep-trace',
                      '--bvs', dti_par])
@@ -364,12 +363,12 @@ def test_parrec2nii_with_data():
         bvecs_LAS = bvecs_LPS * [1, -1, 1]
         assert_almost_equal(np.loadtxt('DTI.bvecs'), bvecs_LAS.T)
         # Dwell time
-        assert_false(exists('DTI.dwell_time'))
+        assert not exists('DTI.dwell_time')
         # Need field strength if requesting dwell time
         code, _, _, = run_command(
             ['parrec2nii', '--overwrite', '--dwell-time', dti_par],
             check_code=False)
-        assert_equal(code, 1)
+        assert code == 1
         run_command(
             ['parrec2nii', '--overwrite', '--dwell-time',
              '--field-strength', '3', dti_par])
@@ -379,13 +378,13 @@ def test_parrec2nii_with_data():
         assert_almost_equal(float(contents), exp_dwell)
         # ensure trace is removed by default
         run_command(['parrec2nii', '--overwrite', '--bvs', dti_par])
-        assert_true(exists('DTI.bvals'))
-        assert_true(exists('DTI.bvecs'))
+        assert exists('DTI.bvals')
+        assert exists('DTI.bvecs')
         img = load('DTI.nii')
         bvecs_notrace = np.loadtxt('DTI.bvecs').T
         bvals_notrace = np.loadtxt('DTI.bvals')
         data_notrace = img.get_fdata()
-        assert_equal(data_notrace.shape[-1], len(bvecs_notrace))
+        assert data_notrace.shape[-1] == len(bvecs_notrace)
         del img
         # ensure correct volume was removed
         good_mask = np.logical_or((bvecs_trace != 0).any(axis=1),
@@ -405,7 +404,7 @@ def test_parrec2nii_with_data():
 
         # Writes .ordering.csv if requested
         run_command(['parrec2nii', '--overwrite', '--volume-info', dti_par])
-        assert_true(exists('DTI.ordering.csv'))
+        assert exists('DTI.ordering.csv')
         with open('DTI.ordering.csv', 'r') as csvfile:
             csvreader = csv.reader(csvfile, delimiter=',')
             csv_keys = next(csvreader)  # header row
@@ -413,9 +412,8 @@ def test_parrec2nii_with_data():
             for line in csvreader:
                 nlines += 1
 
-        assert_equal(sorted(csv_keys), ['diffusion b value number',
-                                        'gradient orientation number'])
-        assert_equal(nlines, 8)  # 8 volumes present in DTI.PAR
+        assert sorted(csv_keys) == ['diffusion b value number', 'gradient orientation number']
+        assert nlines == 8  # 8 volumes present in DTI.PAR
 
 
 @script_test
@@ -435,30 +433,30 @@ def test_nib_trk2tck():
         # Convert one file.
         cmd = ["nib-trk2tck", simple_trk]
         code, stdout, stderr = run_command(cmd)
-        assert_equal(len(stdout), 0)
-        assert_true(os.path.isfile(simple_tck))
+        assert len(stdout) == 0
+        assert os.path.isfile(simple_tck)
         trk = nib.streamlines.load(simple_trk)
         tck = nib.streamlines.load(simple_tck)
-        assert_array_equal(tck.streamlines.data, trk.streamlines.data)
-        assert_true(isinstance(tck, nib.streamlines.TckFile))
+        assert (tck.streamlines.data == trk.streamlines.data).all()
+        assert isinstance(tck, nib.streamlines.TckFile)
 
         # Skip non TRK files.
         cmd = ["nib-trk2tck", simple_tck]
         code, stdout, stderr = run_command(cmd)
-        assert_true("Skipping non TRK file" in stdout)
+        assert "Skipping non TRK file" in stdout
 
         # By default, refuse to overwrite existing output files.
         cmd = ["nib-trk2tck", simple_trk]
         code, stdout, stderr = run_command(cmd)
-        assert_true("Skipping existing file" in stdout)
+        assert "Skipping existing file" in stdout
 
         # Convert multiple files and with --force.
         cmd = ["nib-trk2tck", "--force", simple_trk, standard_trk]
         code, stdout, stderr = run_command(cmd)
-        assert_equal(len(stdout), 0)
+        assert len(stdout) == 0
         trk = nib.streamlines.load(standard_trk)
         tck = nib.streamlines.load(standard_tck)
-        assert_array_equal(tck.streamlines.data, trk.streamlines.data)
+        assert (tck.streamlines.data == trk.streamlines.data).all()
 
 
 @script_test
@@ -475,33 +473,33 @@ def test_nib_tck2trk():
         # Anatomical image not found as first argument.
         cmd = ["nib-tck2trk", standard_tck, anat]
         code, stdout, stderr = run_command(cmd, check_code=False)
-        assert_equal(code, 2)  # Parser error.
-        assert_true("Expecting anatomical image as first agument" in stderr)
+        assert code == 2  # Parser error.
+        assert "Expecting anatomical image as first agument" in stderr
 
         # Convert one file.
         cmd = ["nib-tck2trk", anat, standard_tck]
         code, stdout, stderr = run_command(cmd)
-        assert_equal(len(stdout), 0)
-        assert_true(os.path.isfile(standard_trk))
+        assert len(stdout) == 0
+        assert os.path.isfile(standard_trk)
         tck = nib.streamlines.load(standard_tck)
         trk = nib.streamlines.load(standard_trk)
-        assert_array_equal(trk.streamlines.data, tck.streamlines.data)
-        assert_true(isinstance(trk, nib.streamlines.TrkFile))
+        assert (trk.streamlines.data == tck.streamlines.data).all()
+        assert isinstance(trk, nib.streamlines.TrkFile)
 
         # Skip non TCK files.
         cmd = ["nib-tck2trk", anat, standard_trk]
         code, stdout, stderr = run_command(cmd)
-        assert_true("Skipping non TCK file" in stdout)
+        assert "Skipping non TCK file" in stdout
 
         # By default, refuse to overwrite existing output files.
         cmd = ["nib-tck2trk", anat, standard_tck]
         code, stdout, stderr = run_command(cmd)
-        assert_true("Skipping existing file" in stdout)
+        assert "Skipping existing file" in stdout
 
         # Convert multiple files and with --force.
         cmd = ["nib-tck2trk", "--force", anat, standard_tck, standard_tck]
         code, stdout, stderr = run_command(cmd)
-        assert_equal(len(stdout), 0)
+        assert len(stdout) == 0
         tck = nib.streamlines.load(standard_tck)
         trk = nib.streamlines.load(standard_trk)
-        assert_array_equal(tck.streamlines.data, trk.streamlines.data)
+        assert (tck.streamlines.data == trk.streamlines.data).all()
