@@ -15,58 +15,59 @@ import warnings
 import numpy as np
 
 from io import BytesIO
-from ..spatialimages import (SpatialHeader, SpatialImage, HeaderDataError,
-                             Header, ImageDataError)
+from ..spatialimages import SpatialHeader, SpatialImage, HeaderDataError, Header
 from ..imageclasses import spatial_axes_first
 
+import pytest
 from unittest import TestCase
-from nose.tools import (assert_true, assert_false, assert_equal,
-                        assert_not_equal, assert_raises)
-from numpy.testing import assert_array_equal, assert_array_almost_equal, assert_warns
+from numpy.testing import assert_array_almost_equal
+
+from ..testing import (
+    bytesio_round_trip,
+    clear_and_catch_warnings,
+    suppress_warnings,
+    memmap_after_ufunc
+)
 
-from .test_helpers import bytesio_round_trip
-from ..testing import (clear_and_catch_warnings, suppress_warnings,
-                       memmap_after_ufunc)
 from ..tmpdirs import InTemporaryDirectory
 from ..deprecator import ExpiredDeprecationError
 from .. import load as top_load
 
-
 def test_header_init():
     # test the basic header
     hdr = Header()
-    assert_equal(hdr.get_data_dtype(), np.dtype(np.float32))
-    assert_equal(hdr.get_data_shape(), (0,))
-    assert_equal(hdr.get_zooms(), (1.0,))
+    assert hdr.get_data_dtype() == np.dtype(np.float32)
+    assert hdr.get_data_shape() == (0,)
+    assert hdr.get_zooms() == (1.0,)
     hdr = Header(np.float64)
-    assert_equal(hdr.get_data_dtype(), np.dtype(np.float64))
-    assert_equal(hdr.get_data_shape(), (0,))
-    assert_equal(hdr.get_zooms(), (1.0,))
+    assert hdr.get_data_dtype() == np.dtype(np.float64)
+    assert hdr.get_data_shape() == (0,)
+    assert hdr.get_zooms() == (1.0,)
     hdr = Header(np.float64, shape=(1, 2, 3))
-    assert_equal(hdr.get_data_dtype(), np.dtype(np.float64))
-    assert_equal(hdr.get_data_shape(), (1, 2, 3))
-    assert_equal(hdr.get_zooms(), (1.0, 1.0, 1.0))
+    assert hdr.get_data_dtype() == np.dtype(np.float64)
+    assert hdr.get_data_shape() == (1, 2, 3)
+    assert hdr.get_zooms() == (1.0, 1.0, 1.0)
     hdr = Header(np.float64, shape=(1, 2, 3), zooms=None)
-    assert_equal(hdr.get_data_dtype(), np.dtype(np.float64))
-    assert_equal(hdr.get_data_shape(), (1, 2, 3))
-    assert_equal(hdr.get_zooms(), (1.0, 1.0, 1.0))
+    assert hdr.get_data_dtype() == np.dtype(np.float64)
+    assert hdr.get_data_shape() == (1, 2, 3)
+    assert hdr.get_zooms() == (1.0, 1.0, 1.0)
     hdr = Header(np.float64, shape=(1, 2, 3), zooms=(3.0, 2.0, 1.0))
-    assert_equal(hdr.get_data_dtype(), np.dtype(np.float64))
-    assert_equal(hdr.get_data_shape(), (1, 2, 3))
-    assert_equal(hdr.get_zooms(), (3.0, 2.0, 1.0))
+    assert hdr.get_data_dtype() == np.dtype(np.float64)
+    assert hdr.get_data_shape() == (1, 2, 3)
+    assert hdr.get_zooms() == (3.0, 2.0, 1.0)
 
 
 def test_from_header():
     # check from header class method.  Note equality checks below,
     # equality methods used here too.
     empty = Header.from_header()
-    assert_equal(Header(), empty)
+    assert Header() == empty
     empty = Header.from_header(None)
-    assert_equal(Header(), empty)
+    assert Header() == empty
     hdr = Header(np.float64, shape=(1, 2, 3), zooms=(3.0, 2.0, 1.0))
     copy = Header.from_header(hdr)
-    assert_equal(hdr, copy)
-    assert_false(hdr is copy)
+    assert hdr == copy
+    assert hdr is not copy
 
     class C(object):
 
@@ -76,25 +77,25 @@ def test_from_header():
 
         def get_zooms(self): return (10.0, 9.0, 8.0)
     converted = Header.from_header(C())
-    assert_true(isinstance(converted, Header))
-    assert_equal(converted.get_data_dtype(), np.dtype('u2'))
-    assert_equal(converted.get_data_shape(), (5, 4, 3))
-    assert_equal(converted.get_zooms(), (10.0, 9.0, 8.0))
+    assert isinstance(converted, Header)
+    assert converted.get_data_dtype() == np.dtype('u2')
+    assert converted.get_data_shape() == (5, 4, 3)
+    assert converted.get_zooms() == (10.0, 9.0, 8.0)
 
 
 def test_eq():
     hdr = Header()
     other = Header()
-    assert_equal(hdr, other)
+    assert hdr == other
     other = Header('u2')
-    assert_not_equal(hdr, other)
+    assert hdr != other
     other = Header(shape=(1, 2, 3))
-    assert_not_equal(hdr, other)
+    assert hdr != other
     hdr = Header(shape=(1, 2))
     other = Header(shape=(1, 2))
-    assert_equal(hdr, other)
+    assert hdr == other
     other = Header(shape=(1, 2), zooms=(2.0, 3.0))
-    assert_not_equal(hdr, other)
+    assert hdr != other
 
 
 def test_copy():
@@ -102,51 +103,50 @@ def test_copy():
     hdr = Header(np.float64, shape=(1, 2, 3), zooms=(3.0, 2.0, 1.0))
     hdr_copy = hdr.copy()
     hdr.set_data_shape((4, 5, 6))
-    assert_equal(hdr.get_data_shape(), (4, 5, 6))
-    assert_equal(hdr_copy.get_data_shape(), (1, 2, 3))
+    assert hdr.get_data_shape() == (4, 5, 6)
+    assert hdr_copy.get_data_shape() == (1, 2, 3)
     hdr.set_zooms((4, 5, 6))
-    assert_equal(hdr.get_zooms(), (4, 5, 6))
-    assert_equal(hdr_copy.get_zooms(), (3, 2, 1))
+    assert hdr.get_zooms() == (4, 5, 6)
+    assert hdr_copy.get_zooms() == (3, 2, 1)
     hdr.set_data_dtype(np.uint8)
-    assert_equal(hdr.get_data_dtype(), np.dtype(np.uint8))
-    assert_equal(hdr_copy.get_data_dtype(), np.dtype(np.float64))
+    assert hdr.get_data_dtype() == np.dtype(np.uint8)
+    assert hdr_copy.get_data_dtype() == np.dtype(np.float64)
 
 
 def test_shape_zooms():
     hdr = Header()
     hdr.set_data_shape((1, 2, 3))
-    assert_equal(hdr.get_data_shape(), (1, 2, 3))
-    assert_equal(hdr.get_zooms(), (1.0, 1.0, 1.0))
+    assert hdr.get_data_shape() == (1, 2, 3)
+    assert hdr.get_zooms() == (1.0, 1.0, 1.0)
     hdr.set_zooms((4, 3, 2))
-    assert_equal(hdr.get_zooms(), (4.0, 3.0, 2.0))
+    assert hdr.get_zooms() == (4.0, 3.0, 2.0)
     hdr.set_data_shape((1, 2))
-    assert_equal(hdr.get_data_shape(), (1, 2))
-    assert_equal(hdr.get_zooms(), (4.0, 3.0))
+    assert hdr.get_data_shape() == (1, 2)
+    assert hdr.get_zooms() == (4.0, 3.0)
     hdr.set_data_shape((1, 2, 3))
-    assert_equal(hdr.get_data_shape(), (1, 2, 3))
-    assert_equal(hdr.get_zooms(), (4.0, 3.0, 1.0))
+    assert hdr.get_data_shape() == (1, 2, 3)
+    assert hdr.get_zooms() == (4.0, 3.0, 1.0)
     # null shape is (0,)
     hdr.set_data_shape(())
-    assert_equal(hdr.get_data_shape(), (0,))
-    assert_equal(hdr.get_zooms(), (1.0,))
+    assert hdr.get_data_shape() == (0,)
+    assert hdr.get_zooms() == (1.0,)
     # zooms of wrong lengths raise error
-    assert_raises(HeaderDataError, hdr.set_zooms, (4.0, 3.0))
-    assert_raises(HeaderDataError,
-                  hdr.set_zooms,
-                  (4.0, 3.0, 2.0, 1.0))
+    with pytest.raises(HeaderDataError):
+        hdr.set_zooms((4.0, 3.0))
+    with pytest.raises(HeaderDataError):
+        hdr.set_zooms((4.0, 3.0, 2.0, 1.0))
     # as do negative zooms
-    assert_raises(HeaderDataError,
-                  hdr.set_zooms,
-                  (4.0, 3.0, -2.0))
+    with pytest.raises(HeaderDataError):
+        hdr.set_zooms((4.0, 3.0, -2.0))
 
 
 def test_data_dtype():
     hdr = Header()
-    assert_equal(hdr.get_data_dtype(), np.dtype(np.float32))
+    assert hdr.get_data_dtype() == np.dtype(np.float32)
     hdr.set_data_dtype(np.float64)
-    assert_equal(hdr.get_data_dtype(), np.dtype(np.float64))
+    assert hdr.get_data_dtype() == np.dtype(np.float64)
     hdr.set_data_dtype('u2')
-    assert_equal(hdr.get_data_dtype(), np.dtype(np.uint16))
+    assert hdr.get_data_dtype() == np.dtype(np.uint16)
 
 
 def test_affine():
@@ -162,8 +162,7 @@ def test_affine():
                                [0, 2, 0, -1],
                                [0, 0, 1, -1],
                                [0, 0, 0, 1]])
-    assert_array_equal(hdr.get_base_affine(),
-                       hdr.get_best_affine())
+    assert np.array_equal(hdr.get_base_affine(), hdr.get_best_affine())
 
 
 def test_read_data():
@@ -174,22 +173,19 @@ def test_read_data():
         fobj = BytesIO()
         data = np.arange(6).reshape((1, 2, 3))
         hdr.data_to_fileobj(data, fobj)
-        assert_equal(fobj.getvalue(),
-                     data.astype(np.int32).tostring(order=order))
+        assert fobj.getvalue() == data.astype(np.int32).tobytes(order=order)
         # data_to_fileobj accepts kwarg 'rescale', but no effect in this case
         fobj.seek(0)
         hdr.data_to_fileobj(data, fobj, rescale=True)
-        assert_equal(fobj.getvalue(),
-                     data.astype(np.int32).tostring(order=order))
+        assert fobj.getvalue() == data.astype(np.int32).tobytes(order=order)
         # data_to_fileobj can be a list
         fobj.seek(0)
         hdr.data_to_fileobj(data.tolist(), fobj, rescale=True)
-        assert_equal(fobj.getvalue(),
-                     data.astype(np.int32).tostring(order=order))
+        assert fobj.getvalue() == data.astype(np.int32).tobytes(order=order)
         # Read data back again
         fobj.seek(0)
         data2 = hdr.data_from_fileobj(fobj)
-        assert_array_equal(data, data2)
+        assert (data == data2).all()
 
 
 class DataLike(object):
@@ -211,33 +207,33 @@ class TestSpatialImage(TestCase):
         arr = np.arange(24, dtype=np.int16).reshape((2, 3, 4))
         aff = np.eye(4)
         img = img_klass(arr, aff)
-        assert_array_equal(img.affine, aff)
+        assert (img.affine == aff).all()
         aff[0, 0] = 99
-        assert_false(np.all(img.affine == aff))
+        assert not np.all(img.affine == aff)
         # header, created by image creation
         ihdr = img.header
         # Pass it back in
         img = img_klass(arr, aff, ihdr)
         # Check modifying header outside does not modify image
         ihdr.set_zooms((4, 5, 6))
-        assert_not_equal(img.header, ihdr)
+        assert img.header != ihdr
 
     def test_float_affine(self):
         # Check affines get converted to float
         img_klass = self.image_class
         arr = np.arange(3, dtype=np.int16)
         img = img_klass(arr, np.eye(4, dtype=np.float32))
-        assert_equal(img.affine.dtype, np.dtype(np.float64))
+        assert img.affine.dtype == np.dtype(np.float64)
         img = img_klass(arr, np.eye(4, dtype=np.int16))
-        assert_equal(img.affine.dtype, np.dtype(np.float64))
+        assert img.affine.dtype == np.dtype(np.float64)
 
     def test_images(self):
         # Assumes all possible images support int16
         # See https://github.com/nipy/nibabel/issues/58
         arr = np.arange(24, dtype=np.int16).reshape((2, 3, 4))
         img = self.image_class(arr, None)
-        assert_array_equal(img.get_fdata(), arr)
-        assert_equal(img.affine, None)
+        assert (img.get_fdata() == arr).all()
+        assert img.affine is None
 
     def test_default_header(self):
         # Check default header is as expected
@@ -246,21 +242,21 @@ class TestSpatialImage(TestCase):
         hdr = self.image_class.header_class()
         hdr.set_data_shape(arr.shape)
         hdr.set_data_dtype(arr.dtype)
-        assert_equal(img.header, hdr)
+        assert img.header == hdr
 
     def test_data_api(self):
         # Test minimal api data object can initialize
         img = self.image_class(DataLike(), None)
         # Shape may be promoted to higher dimension, but may not reorder or
         # change size
-        assert_array_equal(img.get_fdata().flatten(), np.arange(3))
-        assert_equal(img.shape[:1], (3,))
-        assert_equal(np.prod(img.shape), 3)
+        assert (img.get_fdata().flatten() == np.arange(3)).all()
+        assert img.shape[:1] == (3,)
+        assert np.prod(img.shape) == 3
 
     def check_dtypes(self, expected, actual):
         # Some images will want dtypes to be equal including endianness,
         # others may only require the same type
-        assert_equal(expected, actual)
+        assert expected == actual
 
     def test_data_default(self):
         # check that the default dtype comes from the data if the header
@@ -285,10 +281,10 @@ class TestSpatialImage(TestCase):
         img = img_klass(arr, np.eye(4))
         # Shape may be promoted to higher dimension, but may not reorder or
         # change size
-        assert_equal(img.shape[:1], (4,))
-        assert_equal(np.prod(img.shape), 4)
+        assert img.shape[:1] == (4,)
+        assert np.prod(img.shape) == 4
         img = img_klass(np.zeros((2, 3, 4), dtype=np.float32), np.eye(4))
-        assert_equal(img.shape, (2, 3, 4))
+        assert img.shape == (2, 3, 4)
 
     def test_str(self):
         # Check something comes back from string representation
@@ -297,13 +293,13 @@ class TestSpatialImage(TestCase):
         # See https://github.com/nipy/nibabel/issues/58
         arr = np.arange(5, dtype=np.int16)
         img = img_klass(arr, np.eye(4))
-        assert_true(len(str(img)) > 0)
+        assert len(str(img)) > 0
         # Shape may be promoted to higher dimension, but may not reorder or
         # change size
-        assert_equal(img.shape[:1], (5,))
-        assert_equal(np.prod(img.shape), 5)
+        assert img.shape[:1] == (5,)
+        assert np.prod(img.shape) == 5
         img = img_klass(np.zeros((2, 3, 4), dtype=np.int16), np.eye(4))
-        assert_true(len(str(img)) > 0)
+        assert len(str(img)) > 0
 
     def test_get_shape(self):
         # Check that get_shape raises an ExpiredDeprecationError
@@ -311,7 +307,7 @@ class TestSpatialImage(TestCase):
         # Assumes all possible images support int16
         # See https://github.com/nipy/nibabel/issues/58
         img = img_klass(np.arange(1, dtype=np.int16), np.eye(4))
-        with assert_raises(ExpiredDeprecationError):
+        with pytest.raises(ExpiredDeprecationError):
             img.get_shape()
 
     def test_get_fdata(self):
@@ -320,55 +316,57 @@ class TestSpatialImage(TestCase):
         in_data_template = np.arange(24, dtype=np.int16).reshape((2, 3, 4))
         in_data = in_data_template.copy()
         img = img_klass(in_data, None)
-        assert_true(in_data is img.dataobj)
+        assert in_data is img.dataobj
         # The get_fdata method changes the array to floating point type
-        assert_equal(img.get_fdata(dtype='f4').dtype, np.dtype(np.float32))
+        assert img.get_fdata(dtype='f4').dtype == np.dtype(np.float32)
         fdata_32 = img.get_fdata(dtype=np.float32)
-        assert_equal(fdata_32.dtype, np.dtype(np.float32))
+        assert fdata_32.dtype == np.dtype(np.float32)
         # Caching is specific to data dtype.  If we reload with default data
         # type, the cache gets reset
         fdata_32[:] = 99
         # Cache has been modified, we pick up the modifications, but only for
         # the cached data type
-        assert_array_equal(img.get_fdata(dtype='f4'), 99)
+        assert (img.get_fdata(dtype='f4') == 99).all()
         fdata_64 = img.get_fdata()
-        assert_equal(fdata_64.dtype, np.dtype(np.float64))
-        assert_array_equal(fdata_64, in_data)
+        assert fdata_64.dtype == np.dtype(np.float64)
+        assert (fdata_64 == in_data).all()
         fdata_64[:] = 101
-        assert_array_equal(img.get_fdata(dtype='f8'), 101)
-        assert_array_equal(img.get_fdata(), 101)
+        assert (img.get_fdata(dtype='f8') == 101).all()
+        assert (img.get_fdata() == 101).all()
         # Reloading with new data type blew away the float32 cache
-        assert_array_equal(img.get_fdata(dtype='f4'), in_data)
+        assert (img.get_fdata(dtype='f4') == in_data).all()
         img.uncache()
         # Now recaching, is float64
         out_data = img.get_fdata()
-        assert_equal(out_data.dtype, np.dtype(np.float64))
+        assert out_data.dtype == np.dtype(np.float64)
         # Input dtype needs to be floating point
-        assert_raises(ValueError, img.get_fdata, dtype=np.int16)
-        assert_raises(ValueError, img.get_fdata, dtype=np.int32)
+        with pytest.raises(ValueError):
+            img.get_fdata(dtype=np.int16)
+        with pytest.raises(ValueError):
+            img.get_fdata(dtype=np.int32)
         # The cache is filled
         out_data[:] = 42
-        assert_true(img.get_fdata() is out_data)
+        assert img.get_fdata() is out_data
         img.uncache()
-        assert_false(img.get_fdata() is out_data)
+        assert img.get_fdata() is not out_data
         # The 42 has gone now.
-        assert_array_equal(img.get_fdata(), in_data_template)
+        assert (img.get_fdata() == in_data_template).all()
         # If we can save, we can create a proxy image
         if not self.can_save:
             return
         rt_img = bytesio_round_trip(img)
-        assert_false(in_data is rt_img.dataobj)
-        assert_array_equal(rt_img.dataobj, in_data)
+        assert in_data is not rt_img.dataobj
+        assert (rt_img.dataobj == in_data).all()
         out_data = rt_img.get_fdata()
-        assert_array_equal(out_data, in_data)
-        assert_false(rt_img.dataobj is out_data)
-        assert_equal(out_data.dtype, np.dtype(np.float64))
+        assert (out_data == in_data).all()
+        assert rt_img.dataobj is not out_data
+        assert out_data.dtype == np.dtype(np.float64)
         # cache
-        assert_true(rt_img.get_fdata() is out_data)
+        assert rt_img.get_fdata() is out_data
         out_data[:] = 42
         rt_img.uncache()
-        assert_false(rt_img.get_fdata() is out_data)
-        assert_array_equal(rt_img.get_fdata(), in_data)
+        assert rt_img.get_fdata() is not out_data
+        assert (rt_img.get_fdata() == in_data).all()
 
     def test_get_data(self):
         # Test array image and proxy image interface
@@ -377,41 +375,41 @@ class TestSpatialImage(TestCase):
         in_data = in_data_template.copy()
         img = img_klass(in_data, None)
         # Can't slice into the image object:
-        with assert_raises(TypeError) as exception_manager:
+        with pytest.raises(TypeError) as exception_manager:
             img[0, 0, 0]
         # Make sure the right message gets raised:
-        assert_equal(str(exception_manager.exception),
-                     "Cannot slice image objects; consider using "
-                     "`img.slicer[slice]` to generate a sliced image (see "
-                     "documentation for caveats) or slicing image array data "
-                     "with `img.dataobj[slice]` or `img.get_fdata()[slice]`")
-        assert_true(in_data is img.dataobj)
-        with assert_warns(DeprecationWarning):
+        assert (str(exception_manager.value) ==
+                "Cannot slice image objects; consider using "
+                "`img.slicer[slice]` to generate a sliced image (see "
+                "documentation for caveats) or slicing image array data "
+                "with `img.dataobj[slice]` or `img.get_fdata()[slice]`")
+        assert in_data is img.dataobj
+        with pytest.deprecated_call():
             out_data = img.get_data()
-        assert_true(in_data is out_data)
+        assert in_data is out_data
         # and that uncache has no effect
         img.uncache()
-        assert_true(in_data is out_data)
-        assert_array_equal(out_data, in_data_template)
+        assert in_data is out_data
+        assert (out_data == in_data_template).all()
         # If we can save, we can create a proxy image
         if not self.can_save:
             return
         rt_img = bytesio_round_trip(img)
-        assert_false(in_data is rt_img.dataobj)
-        assert_array_equal(rt_img.dataobj, in_data)
-        with assert_warns(DeprecationWarning):
+        assert in_data is not rt_img.dataobj
+        assert (rt_img.dataobj == in_data).all()
+        with pytest.deprecated_call():
             out_data = rt_img.get_data()
-        assert_array_equal(out_data, in_data)
-        assert_false(rt_img.dataobj is out_data)
+        assert (out_data == in_data).all()
+        assert rt_img.dataobj is not out_data
         # cache
-        with assert_warns(DeprecationWarning):
-            assert_true(rt_img.get_data() is out_data)
+        with pytest.deprecated_call():
+            assert rt_img.get_data() is out_data
         out_data[:] = 42
         rt_img.uncache()
-        with assert_warns(DeprecationWarning):
-            assert_false(rt_img.get_data() is out_data)
-        with assert_warns(DeprecationWarning):
-            assert_array_equal(rt_img.get_data(), in_data)
+        with pytest.deprecated_call():
+            assert rt_img.get_data() is not out_data
+        with pytest.deprecated_call():
+            assert (rt_img.get_data() == in_data).all()
 
     def test_slicer(self):
         img_klass = self.image_class
@@ -424,11 +422,11 @@ class TestSpatialImage(TestCase):
             img = img_klass(in_data, base_affine.copy())
 
             if not spatial_axes_first(img):
-                with assert_raises(ValueError):
+                with pytest.raises(ValueError):
                     img.slicer
                 continue
 
-            assert_true(hasattr(img.slicer, '__getitem__'))
+            assert hasattr(img.slicer, '__getitem__')
 
             # Note spatial zooms are always first 3, even when
             spatial_zooms = img.header.get_zooms()[:3]
@@ -437,50 +435,48 @@ class TestSpatialImage(TestCase):
             sliceobj = [slice(None, None, 2)] * 3 + \
                 [slice(None)] * (len(dshape) - 3)
             downsampled_img = img.slicer[tuple(sliceobj)]
-            assert_array_equal(downsampled_img.header.get_zooms()[:3],
-                               np.array(spatial_zooms) * 2)
+            assert (downsampled_img.header.get_zooms()[:3] == np.array(spatial_zooms) * 2).all()
 
             max4d = (hasattr(img.header, '_structarr') and
                      'dims' in img.header._structarr.dtype.fields and
                      img.header._structarr['dims'].shape == (4,))
             # Check newaxis and single-slice errors
-            with assert_raises(IndexError):
+            with pytest.raises(IndexError):
                 img.slicer[None]
-            with assert_raises(IndexError):
+            with pytest.raises(IndexError):
                 img.slicer[0]
             # Axes 1 and 2 are always spatial
-            with assert_raises(IndexError):
+            with pytest.raises(IndexError):
                 img.slicer[:, None]
-            with assert_raises(IndexError):
+            with pytest.raises(IndexError):
                 img.slicer[:, 0]
-            with assert_raises(IndexError):
+            with pytest.raises(IndexError):
                 img.slicer[:, :, None]
-            with assert_raises(IndexError):
+            with pytest.raises(IndexError):
                 img.slicer[:, :, 0]
             if len(img.shape) == 4:
                 if max4d:
-                    with assert_raises(ValueError):
+                    with pytest.raises(ValueError):
                         img.slicer[:, :, :, None]
                 else:
                     # Reorder non-spatial axes
-                    assert_equal(img.slicer[:, :, :, None].shape,
-                                 img.shape[:3] + (1,) + img.shape[3:])
+                    assert (img.slicer[:, :, :, None].shape
+                            == img.shape[:3] + (1,) + img.shape[3:])
                 # 4D to 3D using ellipsis or slices
-                assert_equal(img.slicer[..., 0].shape, img.shape[:-1])
-                assert_equal(img.slicer[:, :, :, 0].shape, img.shape[:-1])
+                assert img.slicer[..., 0].shape == img.shape[:-1]
+                assert img.slicer[:, :, :, 0].shape == img.shape[:-1]
             else:
                 # 3D Analyze/NIfTI/MGH to 4D
-                assert_equal(img.slicer[:, :, :, None].shape, img.shape + (1,))
+                assert img.slicer[:, :, :, None].shape == img.shape + (1,)
             if len(img.shape) == 3:
                 # Slices exceed dimensions
-                with assert_raises(IndexError):
+                with pytest.raises(IndexError):
                     img.slicer[:, :, :, :, None]
             elif max4d:
-                with assert_raises(ValueError):
+                with pytest.raises(ValueError):
                     img.slicer[:, :, :, :, None]
             else:
-                assert_equal(img.slicer[:, :, :, :, None].shape,
-                             img.shape + (1,))
+                assert img.slicer[:, :, :, :, None].shape == img.shape + (1,)
 
             # Crop by one voxel in each dimension
             sliced_i = img.slicer[1:]
@@ -489,35 +485,35 @@ class TestSpatialImage(TestCase):
             sliced_ijk = img.slicer[1:, 1:, 1:]
 
             # No scaling change
-            assert_array_equal(sliced_i.affine[:3, :3], img.affine[:3, :3])
-            assert_array_equal(sliced_j.affine[:3, :3], img.affine[:3, :3])
-            assert_array_equal(sliced_k.affine[:3, :3], img.affine[:3, :3])
-            assert_array_equal(sliced_ijk.affine[:3, :3], img.affine[:3, :3])
+            assert (sliced_i.affine[:3, :3] == img.affine[:3, :3]).all()
+            assert (sliced_j.affine[:3, :3] == img.affine[:3, :3]).all()
+            assert (sliced_k.affine[:3, :3] == img.affine[:3, :3]).all()
+            assert (sliced_ijk.affine[:3, :3] == img.affine[:3, :3]).all()
             # Translation
-            assert_array_equal(sliced_i.affine[:, 3], [1, 0, 0, 1])
-            assert_array_equal(sliced_j.affine[:, 3], [0, 1, 0, 1])
-            assert_array_equal(sliced_k.affine[:, 3], [0, 0, 1, 1])
-            assert_array_equal(sliced_ijk.affine[:, 3], [1, 1, 1, 1])
+            assert (sliced_i.affine[:, 3] == [1, 0, 0, 1]).all()
+            assert (sliced_j.affine[:, 3] == [0, 1, 0, 1]).all()
+            assert (sliced_k.affine[:, 3] == [0, 0, 1, 1]).all()
+            assert (sliced_ijk.affine[:, 3] == [1, 1, 1, 1]).all()
 
             # No change to affines with upper-bound slices
-            assert_array_equal(img.slicer[:1, :1, :1].affine, img.affine)
+            assert (img.slicer[:1, :1, :1].affine == img.affine).all()
 
             # Yell about step = 0
-            with assert_raises(ValueError):
+            with pytest.raises(ValueError):
                 img.slicer[:, ::0]
-            with assert_raises(ValueError):
+            with pytest.raises(ValueError):
                 img.slicer.slice_affine((slice(None), slice(None, None, 0)))
 
             # Don't permit zero-length slices
-            with assert_raises(IndexError):
+            with pytest.raises(IndexError):
                 img.slicer[:0]
 
             # No fancy indexing
-            with assert_raises(IndexError):
+            with pytest.raises(IndexError):
                 img.slicer[[0]]
-            with assert_raises(IndexError):
+            with pytest.raises(IndexError):
                 img.slicer[[-1]]
-            with assert_raises(IndexError):
+            with pytest.raises(IndexError):
                 img.slicer[[0], [-1]]
 
             # Check data is consistent with slicing numpy arrays
@@ -534,14 +530,14 @@ class TestSpatialImage(TestCase):
                         pass
                     else:
                         sliced_data = in_data[sliceobj]
-                        with assert_warns(DeprecationWarning):
-                            assert_array_equal(sliced_data, sliced_img.get_data())
-                        assert_array_equal(sliced_data, sliced_img.get_fdata())
-                        assert_array_equal(sliced_data, sliced_img.dataobj)
-                        assert_array_equal(sliced_data, img.dataobj[sliceobj])
-                        with assert_warns(DeprecationWarning):
-                            assert_array_equal(sliced_data, img.get_data()[sliceobj])
-                        assert_array_equal(sliced_data, img.get_fdata()[sliceobj])
+                        with pytest.deprecated_call():
+                            assert (sliced_data == sliced_img.get_data()).all()
+                        assert (sliced_data == sliced_img.get_fdata()).all()
+                        assert (sliced_data == sliced_img.dataobj).all()
+                        assert (sliced_data == img.dataobj[sliceobj]).all()
+                        with pytest.deprecated_call():
+                            assert (sliced_data == img.get_data()[sliceobj]).all()
+                        assert (sliced_data == img.get_fdata()[sliceobj]).all()
 
     def test_api_deprecations(self):
 
@@ -563,13 +559,13 @@ class TestSpatialImage(TestCase):
         bio = BytesIO()
         file_map = FakeImage.make_file_map({'image': bio})
 
-        with assert_raises(ExpiredDeprecationError):
+        with pytest.raises(ExpiredDeprecationError):
             img.to_files(file_map)
-        with assert_raises(ExpiredDeprecationError):
+        with pytest.raises(ExpiredDeprecationError):
             img.to_filespec('an_image')
-        with assert_raises(ExpiredDeprecationError):
+        with pytest.raises(ExpiredDeprecationError):
             FakeImage.from_files(file_map)
-        with assert_raises(ExpiredDeprecationError):
+        with pytest.raises(ExpiredDeprecationError):
             FakeImage.filespec_to_files('an_image')
 
 
@@ -634,28 +630,27 @@ class MmapImageMixin(object):
                     back_img = func(param1, **kwargs)
                     back_data = np.asanyarray(back_img.dataobj)
                     if expected_mode is None:
-                        assert_false(isinstance(back_data, np.memmap),
-                                     'Should not be a %s' % img_klass.__name__)
+                        assert not isinstance(back_data, np.memmap), 'Should not be a %s' % img_klass.__name__
                     else:
-                        assert_true(isinstance(back_data, np.memmap),
-                                    'Not a %s' % img_klass.__name__)
+                        assert isinstance(back_data, np.memmap), 'Not a %s' % img_klass.__name__
                         if self.check_mmap_mode:
-                            assert_equal(back_data.mode, expected_mode)
+                            assert back_data.mode == expected_mode
                     del back_img, back_data
                 # Check that mmap is keyword-only
-                assert_raises(TypeError, func, param1, True)
+                with pytest.raises(TypeError):
+                    func(param1, True)
                 # Check invalid values raise error
-                assert_raises(ValueError, func, param1, mmap='rw')
-                assert_raises(ValueError, func, param1, mmap='r+')
+                with pytest.raises(ValueError):
+                    func(param1, mmap='rw')
+                with pytest.raises(ValueError):
+                    func(param1, mmap='r+')
 
 
 def test_header_deprecated():
-    with clear_and_catch_warnings() as w:
-        warnings.simplefilter('always', DeprecationWarning)
-
+    with pytest.deprecated_call() as w:
         class MyHeader(Header):
             pass
-        assert_equal(len(w), 0)
 
+        assert len(w) == 0
         MyHeader()
-        assert_equal(len(w), 1)
+        assert len(w) == 1
