@@ -20,13 +20,11 @@ import gzip
 import bz2
 import threading
 import time
-import pytest
 
 import numpy as np
 
 from ..tmpdirs import InTemporaryDirectory
 from ..openers import ImageOpener
-from .. import volumeutils
 from ..volumeutils import (array_from_file,
                            _is_compressed_fobj,
                            array_to_file,
@@ -57,10 +55,9 @@ from ..deprecator import ExpiredDeprecationError
 
 from numpy.testing import (assert_array_almost_equal,
                            assert_array_equal)
-from nose.tools import assert_raises
+import pytest
 
-from ..testing_pytest import (assert_dt_equal, assert_allclose_safely,
-                              suppress_warnings, clear_and_catch_warnings)
+from ..testing import assert_dt_equal, assert_allclose_safely, suppress_warnings
 
 #: convenience variables for numpy types
 FLOAT_TYPES = np.sctypes['float']
@@ -72,11 +69,11 @@ NUMERIC_TYPES = CFLOAT_TYPES + IUINT_TYPES
 
 
 def test_deprecated_functions():
-    with assert_raises(ExpiredDeprecationError):
+    with pytest.raises(ExpiredDeprecationError):
         scale_min_max(0, 1, np.uint8, True)
-    with assert_raises(ExpiredDeprecationError):
+    with pytest.raises(ExpiredDeprecationError):
         calculate_scale(np.array([-2, -1], dtype=np.int8), np.uint8, True)
-    with assert_raises(ExpiredDeprecationError):
+    with pytest.raises(ExpiredDeprecationError):
         can_cast(np.float32, np.float32)
 
 
@@ -112,7 +109,7 @@ def test_fobj_string_assumptions():
             in_arr = np.arange(n, dtype=dtype)
             # Write array to file
             fobj_w = opener(fname, 'wb')
-            fobj_w.write(in_arr.tostring())
+            fobj_w.write(in_arr.tobytes())
             fobj_w.close()
             # Read back from file
             fobj_r = opener(fname, 'rb')
@@ -188,7 +185,7 @@ def test_array_from_file_mmap():
         for dt in (np.int16, np.float):
             arr = np.arange(np.prod(shape), dtype=dt).reshape(shape)
             with open('test.bin', 'wb') as fobj:
-                fobj.write(arr.tostring(order='F'))
+                fobj.write(arr.tobytes(order='F'))
             with open('test.bin', 'rb') as fobj:
                 res = array_from_file(shape, dt, fobj)
                 assert_array_equal(res, arr)
@@ -225,7 +222,7 @@ def test_array_from_file_mmap():
 
 def buf_chk(in_arr, out_buf, in_buf, offset):
     ''' Write contents of in_arr into fileobj, read back, check same '''
-    instr = b' ' * offset + in_arr.tostring(order='F')
+    instr = b' ' * offset + in_arr.tobytes(order='F')
     out_buf.write(instr)
     out_buf.flush()
     if in_buf is None:  # we're using in_buf from out_buf
@@ -251,7 +248,7 @@ def test_array_from_file_openers():
             with Opener(fname, 'wb') as out_buf:
                 if offset != 0:  # avoid https://bugs.python.org/issue16828
                     out_buf.write(b' ' * offset)
-                out_buf.write(in_arr.tostring(order='F'))
+                out_buf.write(in_arr.tobytes(order='F'))
             with Opener(fname, 'rb') as in_buf:
                 out_arr = array_from_file(shape, dtype, in_buf, offset)
                 assert_array_almost_equal(in_arr, out_arr)
@@ -277,7 +274,7 @@ def test_array_from_file_reread():
             # Write array to file
             fobj_w = opener() if is_bio else opener(fname, 'wb')
             fobj_w.write(b' ' * offset)
-            fobj_w.write(in_arr.tostring(order=order))
+            fobj_w.write(in_arr.tobytes(order=order))
             if is_bio:
                 fobj_r = fobj_w
             else:
@@ -681,7 +678,7 @@ def test_a2f_nan2zero_range():
         with pytest.raises(ValueError):
             write_return(arr_no_nan, fobj, np.int8, intercept=129)
         # OK with nan2zero false, but we get whatever nan casts to
-        nan_cast = np.array(np.nan).astype(np.int8)
+        nan_cast = np.array(np.nan, dtype=dt).astype(np.int8)
         back_arr = write_return(arr, fobj, np.int8, intercept=129, nan2zero=False)
         assert_array_equal([-128, -128, -128, nan_cast], back_arr)
         # divslope
@@ -1021,8 +1018,7 @@ def test_fname_ext_ul_case():
 def test_allopen():
     # This import into volumeutils is for compatibility.  The code is the
     # ``openers`` module.
-    with clear_and_catch_warnings() as w:
-        warnings.filterwarnings('once', category=DeprecationWarning)
+    with pytest.deprecated_call() as w:
         # Test default mode is 'rb'
         fobj = allopen(__file__)
         # Check we got the deprecation warning
